@@ -71,12 +71,6 @@
 //
 //#define DEBUG_MOUSE_COORDINATES 1
 
-// Define the following macro if you want to skip rendering
-// when late on FPS time.
-// This is an experimental feature, so it's off by default
-//#define SKIP_RENDERING_IF_LATE 1
-
-
 namespace gnash {
 
 struct Gui::Display
@@ -181,7 +175,9 @@ Gui::Gui(unsigned long xid, float scale, bool loop, RunResources& r)
 
 Gui::~Gui()
 {
-    if ( _movieDef.get() ) log_debug("~Gui - _movieDef refcount: %d", _movieDef->get_ref_count());
+    if ( _movieDef.get() ) {
+        log_debug("~Gui - _movieDef refcount: %d", _movieDef->get_ref_count());
+    }
 
 #ifdef GNASH_FPS_DEBUG
     if ( fps_timer_interval ) {
@@ -230,20 +226,20 @@ Gui::quit()
 void
 Gui::hideMenu()
 {
-    log_unimpl(_("Menu hiding not yet supported in this GUI"));
+    LOG_ONCE(log_unimpl(_("Menu show/hide not yet supported in this GUI")));
 }
 
 bool
 Gui::showMouse(bool /* show */)
 {
-	LOG_ONCE(log_unimpl(_("Mouse show/hide not yet supported in this GUI")));
-   	return true;
+    LOG_ONCE(log_unimpl(_("Mouse show/hide not yet supported in this GUI")));
+    return true;
 }
 
 void
 Gui::showMenu(bool /* show */)
 {
-	LOG_ONCE(log_unimpl(_("menushow not yet supported in this GUI")));
+    LOG_ONCE(log_unimpl(_("Menu show/hide not yet supported in this GUI")));
 }
 
 void
@@ -262,20 +258,19 @@ void
 Gui::toggleFullscreen()
 {
     /// Sends request to Gnash core to change display state.
-	if (_fullscreen) {
-		_stage->setStageDisplayState(movie_root::DISPLAYSTATE_NORMAL);
-	}
-	else {
-		_stage->setStageDisplayState(movie_root::DISPLAYSTATE_FULLSCREEN);
-	} 
+    if (_fullscreen) {
+        _stage->setStageDisplayState(movie_root::DISPLAYSTATE_NORMAL);
+    } else {
+        _stage->setStageDisplayState(movie_root::DISPLAYSTATE_FULLSCREEN);
+    } 
 }
 
 void
 Gui::restart()
 {
-	_stage->reset();
-	_started = false;
-	start();
+    _stage->reset();
+    _started = false;
+    start();
 }
 
 void
@@ -284,7 +279,7 @@ Gui::updateStageMatrix()
     if (!_stage) {
         // When VM initializes, we'll get a call to resize_view, which
         // would call us again.
-        //log_debug("Can't update stage matrix till VM is initialized");
+        log_error(_("Can't update stage matrix till VM is initialized"));
         return;
     }
     
@@ -307,16 +302,15 @@ Gui::updateStageMatrix()
             // stage matrix that returns nan values.			
             _xscale = (swfwidth == 0.0f) ? 1.0f : _width / swfwidth;
             _yscale = (swfheight == 0.0f) ? 1.0f : _height / swfheight;
-            
+
             // Scale proportionally, using smallest scale
             if (_xscale < _yscale) {
                 _yscale = _xscale;
-            } 
-            else if (_yscale < _xscale) {
+            } else if (_yscale < _xscale) {
                 _xscale = _yscale;
             }
             break;
-        
+
         case movie_root::SCALEMODE_NOBORDER:
             // set new scale value ( user-pixel / pseudo-pixel )
             _xscale = (swfwidth == 0.0f) ? 1.0f : _width / swfwidth;
@@ -325,8 +319,7 @@ Gui::updateStageMatrix()
             // Scale proportionally, using biggest scale
             if (_xscale > _yscale) {
                 _yscale = _xscale;
-            } 
-            else if (_yscale > _xscale) {
+            } else if (_yscale > _xscale) {
                 _xscale = _yscale;
             }
             break;
@@ -338,7 +331,7 @@ Gui::updateStageMatrix()
             break;
         
         default:
-            log_error("Invalid scaleMode %d", scaleMode);
+            log_error(_("Invalid scaleMode %d"), scaleMode);
             break;
     }
     
@@ -352,66 +345,66 @@ Gui::updateStageMatrix()
     
     // Handle horizontal alignment
     switch ( halign ) {
-    case movie_root::STAGE_H_ALIGN_L:
-        {
-            // _xoffset=0 is fine
-            break;
-        }
+      case movie_root::STAGE_H_ALIGN_L:
+      {
+          // _xoffset=0 is fine
+          break;
+      }
+      
+      case movie_root::STAGE_H_ALIGN_R:
+      {
+          // Offsets in pixels
+          float defWidth = swfwidth *= _xscale;
+          float diffWidth = _width-defWidth;
+          _xoffset = diffWidth;
+          break;
+      }
         
-    case movie_root::STAGE_H_ALIGN_R:
-        {
-            // Offsets in pixels
-            float defWidth = swfwidth *= _xscale;
-            float diffWidth = _width-defWidth;
-            _xoffset = diffWidth;
-            break;
-        }
+      case movie_root::STAGE_V_ALIGN_C:
+      {
+          // Offsets in pixels
+          float defWidth = swfwidth *= _xscale;
+          float diffWidth = _width-defWidth;
+          _xoffset = diffWidth/2.0;
+          break;
+      }
         
-    case movie_root::STAGE_V_ALIGN_C:
-        {
-            // Offsets in pixels
-            float defWidth = swfwidth *= _xscale;
-            float diffWidth = _width-defWidth;
-            _xoffset = diffWidth/2.0;
-            break;
-        }
-        
-    default:
-        {
-            log_error("Invalid horizontal align %d", valign);
-            break;
-        }
+      default:
+      {
+          log_error(_("Invalid horizontal align %d"), valign);
+          break;
+      }
     }
     
     // Handle vertical alignment
     switch ( valign ) {
-    case movie_root::STAGE_V_ALIGN_T:
-        {
-            // _yoffset=0 is fine
-            break;
-        }
+      case movie_root::STAGE_V_ALIGN_T:
+      {
+          // _yoffset=0 is fine
+          break;
+      }
+      
+      case movie_root::STAGE_V_ALIGN_B:
+      {
+          float defHeight = swfheight *= _yscale;
+          float diffHeight = _height-defHeight;
+          _yoffset = diffHeight;
+          break;
+      }
         
-    case movie_root::STAGE_V_ALIGN_B:
-        {
-            float defHeight = swfheight *= _yscale;
-            float diffHeight = _height-defHeight;
-            _yoffset = diffHeight;
-            break;
-        }
+      case movie_root::STAGE_V_ALIGN_C:
+      {
+          float defHeight = swfheight *= _yscale;
+          float diffHeight = _height-defHeight;
+          _yoffset = diffHeight/2.0;
+          break;
+      }
         
-    case movie_root::STAGE_V_ALIGN_C:
-        {
-            float defHeight = swfheight *= _yscale;
-            float diffHeight = _height-defHeight;
-            _yoffset = diffHeight/2.0;
-            break;
-        }
-        
-    default:
-        {
-            log_error("Invalid vertical align %d", valign);
-            break;
-        }
+      default:
+      {
+          log_error(_("Invalid vertical align %d"), valign);
+          break;
+      }
     }
     
     //log_debug("updateStageMatrix: scaleMode:%d, valign:%d, halign:%d",
@@ -435,21 +428,24 @@ Gui::updateStageMatrix()
 void
 Gui::resize_view(int width, int height)
 {
-
-	assert(width>0);
-	assert(height>0);
+    GNASH_REPORT_FUNCTION;
+    
+    assert(width > 0);
+    assert(height > 0);
 
     if (_stage && _started) {
         _stage->setDimensions(width, height);
     }
 
-	_width = width;
-	_height = height;
-	_validbounds.setTo(0, 0, _width, _height);
-
-	updateStageMatrix();
-
-	if ( _stage && _started ) display(_stage);
+    _width = width;
+    _height = height;
+    _validbounds.setTo(0, 0, _width, _height);
+    
+    updateStageMatrix();
+    
+    if ( _stage && _started ) {
+        display(_stage);
+    }
 }
 
 
@@ -471,53 +467,44 @@ Gui::toggleSound()
 void
 Gui::notifyMouseMove(int ux, int uy) 
 {
-	movie_root* m = _stage;
-
-	if ( ! _started ) return;
-
-	if ( _stopped ) return;
-
-	// A stage pseudopixel is user pixel / _xscale wide
-	boost::int32_t x = (ux-_xoffset) / _xscale;
-
-	// A stage pseudopixel is user pixel / _xscale high
-	boost::int32_t y = (uy-_yoffset) / _yscale;
-
+    movie_root* m = _stage;
+    
+    if ( ! _started ) return;
+    
+    if ( _stopped ) return;
+    
+    // A stage pseudopixel is user pixel / _xscale wide
+    boost::int32_t x = (ux-_xoffset) / _xscale;
+    
+    // A stage pseudopixel is user pixel / _xscale high
+    boost::int32_t y = (uy-_yoffset) / _yscale;
+    
 #ifdef DEBUG_MOUSE_COORDINATES
-	log_debug(_("mouse @ %d,%d"), x, y);
+    log_debug("mouse @ %d,%d", x, y);
 #endif
-
-	if ( m->mouseMoved(x, y) )
-	{
-		// any action triggered by the
-		// event required screen refresh
-		display(m);
-	}
+    
+    if ( m->mouseMoved(x, y) ) {
+        // any action triggered by the
+        // event required screen refresh
+        display(m);
+    }
+    
+    DisplayObject* activeEntity = m->getActiveEntityUnderPointer();
+    if ( activeEntity ) {
+        if ( activeEntity->isSelectableTextField() ) {
+            setCursor(CURSOR_INPUT);
+        } else if ( activeEntity->allowHandCursor() ) {
+            setCursor(CURSOR_HAND);
+        } else {
+            setCursor(CURSOR_NORMAL);
+        }
+    } else {
+        setCursor(CURSOR_NORMAL);
+    }
     
-	DisplayObject* activeEntity = m->getActiveEntityUnderPointer();
-	if ( activeEntity )
-	{
-		if ( activeEntity->isSelectableTextField() )
-		{
-			setCursor(CURSOR_INPUT);
-		}
-		else if ( activeEntity->allowHandCursor() )
-		{
-			setCursor(CURSOR_HAND);
-		}
-		else
-		{
-			setCursor(CURSOR_NORMAL);
-		}
-	}
-	else
-	{
-		setCursor(CURSOR_NORMAL);
-	}
-
 #ifdef ENABLE_KEYBOARD_MOUSE_MOVEMENTS
-	_xpointer = ux;
-	_ypointer = uy;
+    _xpointer = ux;
+    _ypointer = uy;
 #endif
 
 
@@ -526,33 +513,33 @@ Gui::notifyMouseMove(int ux, int uy)
 void
 Gui::notifyMouseWheel(int delta)
 {
-	movie_root* m = _stage;
-	assert(m);
+    movie_root* m = _stage;
+    assert(m);
 
     if (!_started) return;
     if (_stopped) return;
 
-	if (m->mouseWheel(delta)) {
-		// any action triggered by the
-		// event required screen refresh
-		display(m);
-	}
+    if (m->mouseWheel(delta)) {
+        // any action triggered by the
+        // event required screen refresh
+        display(m);
+    }
 } 
 
 void
 Gui::notifyMouseClick(bool mouse_pressed) 
 {
-	movie_root* m = _stage;
-	assert(m);
+    movie_root* m = _stage;
+    assert(m);
 
     if (!_started) return;
     if (_stopped) return;
 
-	if (m->mouseClick(mouse_pressed)) {
-		// any action triggered by the
-		// event required screen refresh
-		display(m);
-	}
+    if (m->mouseClick(mouse_pressed)) {
+        // any action triggered by the
+        // event required screen refresh
+        display(m);
+    }
 }
 
 void
@@ -572,7 +559,7 @@ void
 Gui::notify_key_event(gnash::key::code k, int modifier, bool pressed) 
 {
 
-	/* Handle GUI shortcuts */
+    // Handle GUI shortcuts
     if (pressed) {
         if (k == gnash::key::ESCAPE) {
             if (isFullscreen()) {
@@ -629,7 +616,7 @@ Gui::notify_key_event(gnash::key::code k, int modifier, bool pressed)
               case gnash::key::EQUALS:
               {
                   if (_stage) {
-                      const float fps = _stage->frameRate();
+                      const float fps = _stage->getRootMovie().frameRate();
                       // Min interval allowed: 1/100 second (100FPS)
                       const size_t ni = 1000.0/fps;
                       setInterval(ni);
@@ -704,160 +691,155 @@ Gui::display(movie_root* m)
     assert(m == _stage); // why taking this arg ??
 
     assert(_started);
-
-	InvalidatedRanges changed_ranges;
-	bool redraw_flag;
-
-	// Should the frame be rendered completely, even if it did not change?
+    
+    InvalidatedRanges changed_ranges;
+    bool redraw_flag;
+    
+    // Should the frame be rendered completely, even if it did not change?
 #ifdef FORCE_REDRAW
-  redraw_flag = true;
+    redraw_flag = true;
 #else	
-	redraw_flag = _redraw_flag || want_redraw();
+    redraw_flag = _redraw_flag || want_redraw();
 #endif	
+    
+    // reset class member if we do a redraw now
+    if (redraw_flag) _redraw_flag=false;
+    
+    // Find out the surrounding frame of all characters which
+    // have been updated. This just checks what region of the stage has changed
+    // due to ActionScript code, the timeline or user events. The GUI can still
+    // choose to render a different part of the stage. 
+    //
+    if (!redraw_flag) {
+        
+        // choose snapping ranges factor 
+        changed_ranges.setSnapFactor(1.3f);  
 	
-	// reset class member if we do a redraw now
-	if (redraw_flag) _redraw_flag=false;
-
-	// Find out the surrounding frame of all characters which
-	// have been updated. This just checks what region of the stage has changed
-	// due to ActionScript code, the timeline or user events. The GUI can still
-	// choose to render a different part of the stage. 
-	//
-	if (!redraw_flag) {
-		
-		// choose snapping ranges factor 
-		changed_ranges.setSnapFactor(1.3f);  
-			
-		// Use multi ranges only when GUI/Renderer supports it
-		// (Useless CPU overhead, otherwise)
-		changed_ranges.setSingleMode(!want_multiple_regions());
-
-		// scan through all sprites to compute invalidated bounds  
-		m->add_invalidated_bounds(changed_ranges, false);
-		
-		// grow ranges by a 2 pixels to avoid anti-aliasing issues		
-		changed_ranges.growBy(40.0f / _xscale);
-		
-		// optimize ranges
-		changed_ranges.combineRanges();
-		
-	}
+        // Use multi ranges only when GUI/Renderer supports it
+        // (Useless CPU overhead, otherwise)
+        changed_ranges.setSingleMode(!want_multiple_regions());
+        
+        // scan through all sprites to compute invalidated bounds  
+        m->add_invalidated_bounds(changed_ranges, false);
+	
+        // grow ranges by a 2 pixels to avoid anti-aliasing issues		
+        changed_ranges.growBy(40.0f / _xscale);
+	
+        // optimize ranges
+        changed_ranges.combineRanges();	
+    }
     
     // TODO: Remove this and want_redraw to avoid confusion!?
-	if (redraw_flag)  {
-		changed_ranges.setWorld();
-	}
-	
-	// DEBUG ONLY:
-  // This is a good place to inspect the invalidated bounds state. Enable
-  // the following block (and parts of it) if you need to. 
+    if (redraw_flag)  {
+        changed_ranges.setWorld();
+    }
+    
+    // DEBUG ONLY:
+    // This is a good place to inspect the invalidated bounds state. Enable
+    // the following block (and parts of it) if you need to. 
 #if 0
-  {
-    // This may print a huge amount of information, but is useful to analyze
-    // the (visible) object structure of the movie and the flags of the
-    // characters. For example, a characters should have set the 
-    // m_child_invalidated flag if at least one of it's childs has the
-    // invalidated flag set.
-    log_debug("DUMPING CHARACTER TREE"); 
-    
-    InfoTree tr;
-    InfoTree::iterator top = tr.begin();
-    _stage->getMovieInfo(tr, top);
-
-    for (InfoTree::iterator i = tr.begin(), e = tr.end();
-            i != e; ++i) {
-        std::cout << std::string(tr.depth(i) * 2, ' ') << i->first << ": " << 
-            i->second << std::endl;
+    {
+        // This may print a huge amount of information, but is useful to analyze
+        // the (visible) object structure of the movie and the flags of the
+        // characters. For example, a characters should have set the 
+        // m_child_invalidated flag if at least one of it's childs has the
+        // invalidated flag set.
+        log_debug("DUMPING CHARACTER TREE"); 
+        
+        InfoTree tr;
+        InfoTree::iterator top = tr.begin();
+        _stage->getMovieInfo(tr, top);
+        
+        for (InfoTree::iterator i = tr.begin(), e = tr.end();
+             i != e; ++i) {
+            std::cout << std::string(tr.depth(i) * 2, ' ') << i->first << ": " << 
+                i->second << std::endl;
+        }
+        
+        
+        // less verbose, and often necessary: see the exact coordinates of the
+        // invalidated bounds (mainly to see if it's NULL or something else).	
+        std::cout << "Calculated changed ranges: " << changed_ranges << "\n";
     }
-
-
-    // less verbose, and often necessary: see the exact coordinates of the
-    // invalidated bounds (mainly to see if it's NULL or something else).	
-    std::cout << "Calculated changed ranges: " << changed_ranges << "\n";
-  }
 #endif
-  
-	// Avoid drawing of stopped movies
-	if ( ! changed_ranges.isNull() ) // use 'else'?
-	{
-		// Tell the GUI(!) that we only need to update this
-		// region. Note the GUI can do whatever it wants with
-		// this information. It may simply ignore the bounds
-		// (which will normally lead into a complete redraw),
-		// or it may extend or shrink the bounds as it likes. So,
-		// by calling set_invalidated_bounds we have no guarantee
-		// that only this part of the stage is rendered again.
+    
+    // Avoid drawing of stopped movies
+    if ( ! changed_ranges.isNull() ) { // use 'else'?
+        // Tell the GUI(!) that we only need to update this
+        // region. Note the GUI can do whatever it wants with
+        // this information. It may simply ignore the bounds
+        // (which will normally lead into a complete redraw),
+        // or it may extend or shrink the bounds as it likes. So,
+        // by calling set_invalidated_bounds we have no guarantee
+        // that only this part of the stage is rendered again.
 #ifdef REGION_UPDATES_DEBUGGING_FULL_REDRAW
-		// redraw the full screen so that only the
-		// *new* invalidated region is visible
-		// (helps debugging)
-		InvalidatedRanges world_ranges;
-		world_ranges.setWorld();
-		setInvalidatedRegions(world_ranges);
+        // redraw the full screen so that only the
+        // *new* invalidated region is visible
+        // (helps debugging)
+        InvalidatedRanges world_ranges;
+        world_ranges.setWorld();
+        setInvalidatedRegions(world_ranges);
 #else
-		setInvalidatedRegions(changed_ranges);
+        setInvalidatedRegions(changed_ranges);
 #endif
-
-		// TODO: should this be called even if we're late ?
-		beforeRendering();
-
-		// Render the frame, if not late.
-		// It's up to the GUI/renderer combination
-		// to do any clipping, if desired.     
-		m->display();
-  
-		// show invalidated region using a red rectangle
-		// (Flash debug style)
-		IF_DEBUG_REGION_UPDATES(
+        
+        // TODO: should this be called even if we're late ?
+        beforeRendering();
+        
+        // Render the frame, if not late.
+        // It's up to the GUI/renderer combination
+        // to do any clipping, if desired.     
+        m->display();
+        
+        // show invalidated region using a red rectangle
+        // (Flash debug style)
+        IF_DEBUG_REGION_UPDATES (
             if (_renderer.get() && !changed_ranges.isWorld()) {
-            
                 for (size_t rno = 0; rno < changed_ranges.size(); rno++) {
-                
                     const geometry::Range2d<int>& bounds = 
                         changed_ranges.getRange(rno);
-
+                    
                     float xmin = bounds.getMinX();
                     float xmax = bounds.getMaxX();
                     float ymin = bounds.getMinY();
                     float ymax = bounds.getMaxY();
-
+                    
                     const std::vector<point> box = boost::assign::list_of
                         (point(xmin, ymin))
                         (point(xmax, ymin))
                         (point(xmax, ymax))
                         (point(xmin, ymax));
-
+                    
                     _renderer->draw_poly(box, rgba(0,0,0,0), rgba(255,0,0,255),
-                            SWFMatrix(), false);
-                        
+                                         SWFMatrix(), false);
+                    
                 }
             }
-		);
-
-		// show frame on screen
-		renderBuffer();
-   	
-	};
-  
-	return true;
+            );
+        
+        // show frame on screen
+        renderBuffer();	
+    };
+    
+    return true;
 }
 
 void
 Gui::play()
 {
     if ( ! _stopped ) return;
-
+    
     _stopped = false;
-    if ( ! _started ) start();
-    else
-    {
+    if ( ! _started ) {
+        start();
+    } else {
         assert (_stage);
         // @todo since we registered the sound handler, shouldn't we know
         //       already what it is ?!
         sound::sound_handler* s = _stage->runResources().soundHandler();
         if ( s ) s->unpause();
 
-        log_debug("Starting virtual clock");
+        // log_debug("Starting virtual clock");
         _virtualClock.resume();
     }
 
@@ -880,7 +862,7 @@ Gui::stop()
     sound::sound_handler* s = _stage->runResources().soundHandler();
     if ( s ) s->pause();
 
-    log_debug("Pausing virtual clock");
+    // log_debug("Pausing virtual clock");
     _virtualClock.pause();
 
     stopHook();
@@ -904,7 +886,7 @@ Gui::pause()
     if (s) s->pause();
     _stopped = true;
 
-    log_debug("Pausing virtual clock");
+    // log_debug("Pausing virtual clock");
     _virtualClock.pause();
 
     stopHook();
@@ -915,7 +897,7 @@ Gui::start()
 {
     assert ( ! _started );
     if (_stopped) {
-        log_debug("Gui is in stop mode, won't start application");
+        log_error(_("GUI is in stop mode, won't start application"));
         return;
     }
 
@@ -938,9 +920,8 @@ Gui::start()
         s->unpause();
     }
     _started = true;
-    
 
-    log_debug("Starting virtual clock");
+    // log_debug("Starting virtual clock");
     _virtualClock.resume();
 
 }
@@ -948,8 +929,6 @@ Gui::start()
 bool
 Gui::advanceMovie(bool doDisplay)
 {
-
-
     if (isStopped()) {
         return false;
     }
@@ -969,14 +948,14 @@ Gui::advanceMovie(bool doDisplay)
     // Advance movie by one frame
     const bool advanced = m->advance();
 #else
-    const size_t cur_frame = m->getRootMovie()->get_current_frame();
-    const size_t tot_frames = m->getRootMovie()->get_frame_count();
+    const size_t cur_frame = m->getRootMovie().get_current_frame();
+    const size_t tot_frames = m->getRootMovie().get_frame_count();
     const bool advanced = m->advance();
     
     m->getRootMovie().ensureFrameLoaded(tot_frames);
     m->goto_frame(cur_frame + 1);
     m->getRootMovie().setPlayState(gnash::MovieClip::PLAYSTATE_PLAY);
-    log_debug(_("Frame %d"), m->get_current_frame());
+    // log_debug("Frame %d", m->getRootMovie().get_current_frame());
 #endif
     
 #ifdef GNASH_FPS_DEBUG
@@ -986,37 +965,23 @@ Gui::advanceMovie(bool doDisplay)
     }
 #endif
     
-#ifdef SKIP_RENDERING_IF_LATE
-    // We want to skip rendering IFF it's time to advance again.
-    // We'll ask the stage about it
-    if (_stage->timeToNextFrame() <= 0) {
-
-        // or should it be if advanced ?
-        if (doDisplay) {
-            // TODO: take note of a frame drop (count them)
-            //log_debug("Frame rendering dropped due to being late");
-#ifdef GNASH_FPS_DEBUG
-            ++frames_dropped;
-#endif
-        }
-        doDisplay = false;
+    if (doDisplay && visible()) {
+        display(m);
     }
-#endif // ndef SKIP_RENDERING_IF_LATE
-
-	if (doDisplay && visible()) display(m);
-
-	if (!loops()) {
-		size_t curframe = m->get_current_frame(); // can be 0 on malformed SWF
-		const gnash::MovieClip& si = m->getRootMovie();
-		if (curframe + 1 >= si.get_frame_count()) {
-			quit(); 
-		}
-	}
-
+    
+    if (!loops()) {
+        // can be 0 on malformed SWF
+        const size_t curframe = m->getRootMovie().get_current_frame(); 
+        const MovieClip& si = m->getRootMovie();
+        if (curframe + 1 >= si.get_frame_count()) {
+            quit(); 
+        }
+    }
+    
     if (_screenShotter.get() && _renderer.get()) {
         _screenShotter->screenShot(*_renderer, _advances, doDisplay ? 0 : &dis);
     }
-
+    
     // Only increment advances and check for exit condition when we've
     // really changed frame.
     if (advanced) {
@@ -1119,7 +1084,7 @@ Gui::getMovieInfo() const
     /// VM top level
     //
     os << "SWF " << vm.getSWFVersion();
-    topIter = tr->insert(topIter, std::make_pair("VM version", os.str()));
+    topIter = tr->insert(topIter, std::make_pair("Root SWF version", os.str()));
 
     // This short-cut is to avoid a bug in movie_root's getMovieInfo,
     // which relies on the availability of a _rootMovie for doing
@@ -1293,8 +1258,8 @@ Gui::setStage(movie_root* stage)
 bool
 Gui::yesno(const std::string& question)
 {
-    log_error("This gui didn't override 'yesno', assuming 'yes' answer to "
-            "question: %s", question);
+    log_error(_("This GUI didn't override 'yesno', assuming 'yes' answer to "
+                "question: %s"), question);
     return true;
 }
 
@@ -1302,7 +1267,7 @@ void
 Gui::setQuality(Quality q)
 {
     if (!_stage) {
-        log_error("Gui::setQuality called before a movie_root was available");
+        log_error(_("Gui::setQuality called before a movie_root was available"));
         return;
     }
     _stage->setQuality(q);
@@ -1312,39 +1277,13 @@ Quality
 Gui::getQuality() const
 {
     if (!_stage) {
-	log_error("Gui::getQuality called before a movie_root was available");
+	log_error(_("Gui::getQuality called before a movie_root was available"));
 	// just a guess..
 	return QUALITY_HIGH;
     }
     return _stage->getQuality();
 }
 
-void
-Gui::setFDCallback(int fd, boost::function<void ()> callback)
-{
-    log_debug("Setting callback for fd #%d", fd);
-    
-    _fd_callbacks[fd] = callback;
-
-    watchFD(fd);
-}
-
-
-void
-Gui::callCallback(int fd)
-{
-    std::map<int, boost::function<void ()> >::iterator it = _fd_callbacks.find(fd);
-
-    if (it == _fd_callbacks.end()) {
-        log_error("Attempted to call a callback for an unregistered fd.");
-        return;
-    }
-
-    boost::function<void()>& f = it->second;
-
-    f();
-}
-// end of namespace
 }
 
 // local Variables:
