@@ -1,6 +1,7 @@
 // GnashAlgorithm.h: useful templates and functors for generic algorithms
 //
-//   Copyright (C) 2007, 2008, 2009, 2010, 2011 Free Software Foundation, Inc.
+//   Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -21,35 +22,10 @@
 #define GNASH_ALGORITHM_H
 
 #include <algorithm>
-#include <boost/checked_delete.hpp>
-#include <boost/intrusive_ptr.hpp>
-#include <boost/shared_ptr.hpp>
 #include <boost/bind.hpp>
 
 namespace gnash {
 
-/// Retrieve the second element of a container with std::pairs.
-template<typename T>
-struct SecondElement
-{
-    typedef typename T::second_type result_type;
-
-    const result_type& operator()(const T& pair) const {
-        return pair.second;
-    }
-};
-
-/// Retrieve the first element of a container with std::pairs.
-template<typename T>
-struct FirstElement
-{
-    typedef typename T::first_type result_type;
-
-    const result_type& operator()(const T& pair) const {
-        return pair.first;
-    }
-};
-
 /// Return a pointer to a type
 template<typename T>
 struct CreatePointer
@@ -76,7 +52,6 @@ void EraseIf(Container& c, Predicate p)
     }
 }
 
-
 /// Get the size of an array without passing a pointer by mistake
 template<typename T, size_t N>
 size_t
@@ -97,8 +72,10 @@ template<typename T, typename U>
 void
 foreachSecond(T begin, T end, U op)
 {
-    typedef SecondElement<typename std::iterator_traits<T>::value_type> S;
-    std::for_each(begin, end, boost::bind(op, boost::bind(S(), _1)));
+    typedef typename std::iterator_traits<T>::value_type value_type;
+
+    std::for_each(begin, end, boost::bind(op,
+                boost::bind(&value_type::second, _1)));
 }
 
 } // namespace gnash
