@@ -1,6 +1,7 @@
 // GnashImageJpeg.cpp:  Jpeg reader, for Gnash.
 // 
-//   Copyright (C) 2008, 2009, 2010 Free Software Foundation, Inc.
+//   Copyright (C) 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc.
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -16,9 +17,6 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 //
-//
-// Original version by Thatcher Ulrich <tu@tulrich.com> 2002
-//
 // Wrapper for jpeg file operations.  The actual work is done by the
 // IJG jpeg lib.
 
@@ -26,73 +24,58 @@
 #include "gnashconfig.h"
 #endif
 
+#include "GnashImageJpeg.h"
+
+#include <sstream>
+#include <csetjmp>
+#include <boost/noncopyable.hpp>
+#include <algorithm>
+
 #include "utility.h"
 #include "GnashImage.h"
 #include "IOChannel.h"
 #include "log.h"
 #include "GnashException.h"
-#include "GnashImageJpeg.h"
 
-#include <sstream>
-#include <csetjmp>
 
-/// \brief A namespace solely for avoiding name 
-/// conflicts with other external headers.
-namespace jpeg {
-
-// jpeglib.h redefines HAVE_STDLIB_H. This silences
-// the warnings, but it's not good.
+// jpeglib.h redefines HAVE_STDLIB_H.
 #undef HAVE_STDLIB_H
 extern "C" {
+#if defined(_WIN32) && JPEG_LIB_VERSION_MAJOR == 7
+typedef int boolean;
+#endif
 # include <jpeglib.h>
 }		
 #undef HAVE_STDLIB_H
 
-}
+namespace gnash {
+namespace image {
 
-// jpeglib.h is included in the namespace jpeg because otherwise it
-// causes horrible conflicts with qt includes. How do C coders sustain
-// the will to live?
-using namespace jpeg;
+namespace {
 
-#ifdef _WIN32
-typedef jpeg_boolean jpeg_bool_t;
-#else
-typedef jpeg::boolean jpeg_bool_t;
-#endif
-
-namespace gnash
-{
-
-static void
+void
 jpeg_error_exit(j_common_ptr cinfo)
 {
-
     // Set a flag to stop parsing 
-    JpegImageInput* in = static_cast<JpegImageInput*>(cinfo->client_data);
-    
+    JpegInput* in = static_cast<JpegInput*>(cinfo->client_data);
     in->errorOccurred(cinfo->err->jpeg_message_table[cinfo->err->msg_code]); 
-
-    //log_error("failing to abort jpeg parser here (would need a long-jump call)");
 }
 
 
 // Set up some error handlers for the jpeg lib.
-static void
+void
 setup_jpeg_err(jpeg_error_mgr* jerr)
 {
     // Set up defaults.
     jpeg_std_error(jerr);
-
     jerr->error_exit = jpeg_error_exit;
 }
 
-// Helper object for reading jpeg image data.  Basically a thin
 static const int IO_BUF_SIZE = 4096;
 
 // A jpeglib source manager that reads from a IOChannel.  Paraphrased
 // from IJG jpeglib jdatasrc.c.
-class rw_source_IOChannel
+class rw_source_IOChannel : boost::noncopyable
 {
 public:
     jpeg_source_mgr    m_pub;        /* public fields */
@@ -113,18 +96,18 @@ public:
 
     static void init_source(j_decompress_ptr cinfo)
     {
-        rw_source_IOChannel*    src = (rw_source_IOChannel*) cinfo->src;
+        rw_source_IOChannel* src = (rw_source_IOChannel*) cinfo->src;
         src->m_start_of_file = true;
     }
 
     // Read data into our input buffer.  Client calls this
     // when it needs more data from the file.
-    static jpeg_bool_t fill_input_buffer(j_decompress_ptr cinfo)
+    static boolean fill_input_buffer(j_decompress_ptr cinfo)
     {
-        rw_source_IOChannel*    src = (rw_source_IOChannel*) cinfo->src;
+        rw_source_IOChannel* src = (rw_source_IOChannel*) cinfo->src;
 
         // TODO: limit read as requested by caller
-        size_t    bytes_read = src->m_in_stream->read(src->m_buffer, IO_BUF_SIZE);
+        size_t bytes_read = src->m_in_stream->read(src->m_buffer, IO_BUF_SIZE);
 
         if (bytes_read <= 0) {
             // Is the file completely empty?
@@ -133,26 +116,22 @@ public:
                 log_error(_("JPEG: Empty jpeg source stream."));
                 return false;
             }
-            // warn("jpeg end-of-stream");
 
             // Insert a fake EOI marker.
-            src->m_buffer[0] = (JOCTET) 0xFF;
-            src->m_buffer[1] = (JOCTET) JPEG_EOI;
+            src->m_buffer[0] = 0xFF;
+            src->m_buffer[1] = JPEG_EOI;
             bytes_read = 2;
         }
 
         // Hack to work around SWF bug: sometimes data
         // starts with FFD9FFD8, when it should be
         // FFD8FFD9!
-        if (src->m_start_of_file && bytes_read >= 4)
-        {
-            if (src->m_buffer[0] == 0xFF
-                && src->m_buffer[1] == 0xD9 
-                && src->m_buffer[2] == 0xFF
-                && src->m_buffer[3] == 0xD8)
-            {
-                src->m_buffer[1] = 0xD8;
-                src->m_buffer[3] = 0xD9;
+        if (src->m_start_of_file && bytes_read >= 4) {
+
+            const JOCTET wrong[] = { 0xff, 0xd9, 0xff, 0xd8 };
+
+            if (std::equal(src->m_buffer, src->m_buffer + 4, wrong)) {
+                std::swap(src->m_buffer[1], src->m_buffer[3]);
             }
         }
 
@@ -166,7 +145,7 @@ public:
 
     // Called by client when it wants to advance past some
     // uninteresting data.
-    static void    skip_input_data(j_decompress_ptr cinfo, long num_bytes)
+    static void skip_input_data(j_decompress_ptr cinfo, long num_bytes)
     {
         rw_source_IOChannel* src = (rw_source_IOChannel*) cinfo->src;
 
@@ -189,7 +168,7 @@ public:
     }
 
 
-    void    discardPartialBuffer()
+    void discardPartialBuffer()
     {
         // Discard existing bytes in our buffer.
         m_pub.bytes_in_buffer = 0;
@@ -202,9 +181,9 @@ public:
     /// @param instream
     ///     Stream to read from. Ownership always shared with caller.
     ///
-    static void setup(jpeg_decompress_struct* cinfo, boost::shared_ptr<IOChannel> instream)
+    static void setup(jpeg_decompress_struct* cinfo,
+            boost::shared_ptr<IOChannel> instream)
     {
-        // assert(cinfo->src == NULL);
         rw_source_IOChannel* source = new rw_source_IOChannel(instream);
         cinfo->src = (jpeg_source_mgr*)source;
     }
@@ -217,27 +196,28 @@ private:
         m_pub.init_source = init_source;
         m_pub.fill_input_buffer = fill_input_buffer;
         m_pub.skip_input_data = skip_input_data;
-        m_pub.resync_to_restart = jpeg_resync_to_restart;    // use default method
+        // use default method
+        m_pub.resync_to_restart = jpeg_resync_to_restart;
         m_pub.term_source = term_source;
         m_pub.bytes_in_buffer = 0;
         m_pub.next_input_byte = NULL;
     }
 
-    bool _ownSourceStream;
+    const bool _ownSourceStream;
     
     // Source stream
     boost::shared_ptr<IOChannel> m_in_stream;
-    bool    m_start_of_file;        /* have we gotten any data yet? */
-    JOCTET    m_buffer[IO_BUF_SIZE];        /* start of buffer */
-
+    bool m_start_of_file;
+    JOCTET m_buffer[IO_BUF_SIZE];
 
 };
 
+} // unnamed namespace
 
-JpegImageInput::JpegImageInput(boost::shared_ptr<IOChannel> in)
+JpegInput::JpegInput(boost::shared_ptr<IOChannel> in)
     :
-    ImageInput(in),
-    _errorOccurred(false),
+    Input(in),
+    _errorOccurred(0),
     _compressorOpened(false)
 {
     setup_jpeg_err(&m_jerr);
@@ -251,11 +231,11 @@ JpegImageInput::JpegImageInput(boost::shared_ptr<IOChannel> in)
 }
 
 
-JpegImageInput::~JpegImageInput()
+JpegInput::~JpegInput()
 {
-    finishImage();
+    rw_source_IOChannel* src =
+        reinterpret_cast<rw_source_IOChannel*>(m_cinfo.src);
 
-    rw_source_IOChannel* src = reinterpret_cast<rw_source_IOChannel*>(m_cinfo.src);
     delete src;
     m_cinfo.src = NULL;
 
@@ -264,50 +244,48 @@ JpegImageInput::~JpegImageInput()
 
 
 void
-JpegImageInput::discardPartialBuffer()
+JpegInput::discardPartialBuffer()
 {
     rw_source_IOChannel* src = (rw_source_IOChannel*) m_cinfo.src;
 
     // We only have to discard the input buffer after reading the tables.
-    if (src)
-    {
+    if (src) {
         src->discardPartialBuffer();
     }
 }
 
 
 void
-JpegImageInput::readHeader(unsigned int maxHeaderBytes)
+JpegInput::readHeader(unsigned int maxHeaderBytes)
 {
-    if ( setjmp(_jmpBuf) )
-    {
+    if (setjmp(_jmpBuf)) {
         std::stringstream ss;
         ss << _("Internal jpeg error: ") << _errorOccurred;
         throw ParserException(ss.str());
     }
 
-    if ( maxHeaderBytes )
-    {
+    if (maxHeaderBytes) {
         // Read the encoding tables.
         // TODO: how to limit reads ?
-        int ret = jpeg_read_header(&m_cinfo, FALSE);
-        switch (ret)
-        {
-            case JPEG_SUSPENDED: // suspended due to lack of data
-                throw ParserException(_("Lack of data during JPEG header parsing"));
+        const int ret = jpeg_read_header(&m_cinfo, FALSE);
+        switch (ret) {
+            case JPEG_SUSPENDED: 
+                // suspended due to lack of data
+                throw ParserException(_("Lack of data during JPEG "
+                            "header parsing"));
                 break;
-            case JPEG_HEADER_OK: // Found valid image datastream
+            case JPEG_HEADER_OK: 
+                // Found valid image datastream
                 break;
-            case JPEG_HEADER_TABLES_ONLY: // Found valid table-specs-only datastream
+            case JPEG_HEADER_TABLES_ONLY:
+                // Found valid table-specs-only datastream
                 break;
             default:
-                log_debug(_("unexpected: jpeg_read_header returned %d [%s:%d]"),
-                            ret, __FILE__, __LINE__);
+                log_error(_("unexpected: jpeg_read_header returned %d"), ret);
                 break;
         }
 
-        if (_errorOccurred)
-        {
+        if (_errorOccurred) {
             std::stringstream ss;
             ss << _("Internal jpeg error: ") << _errorOccurred;
             throw ParserException(ss.str());
@@ -321,41 +299,41 @@ JpegImageInput::readHeader(unsigned int maxHeaderBytes)
 
 
 void
-JpegImageInput::read()
+JpegInput::read()
 {
     assert(!_compressorOpened);
 
-    if ( setjmp(_jmpBuf) )
-    {
+    if (setjmp(_jmpBuf)) {
         std::stringstream ss;
         ss << _("Internal jpeg error: ") << _errorOccurred;
         throw ParserException(ss.str());
     }
 
-
     // hack, FIXME
-    static const int stateReady = 202;    /* found SOS, ready for start_decompress */
-    while (m_cinfo.global_state != stateReady)
-    {
-        int ret = jpeg_read_header(&m_cinfo, FALSE);
-        switch (ret)
-        {
-            case JPEG_SUSPENDED: // suspended due to lack of data
-                throw ParserException(_("lack of data during JPEG header parsing"));
+    // found SOS, ready for start_decompress
+    static const int stateReady = 202;
+    while (m_cinfo.global_state != stateReady) {
+        const int ret = jpeg_read_header(&m_cinfo, FALSE);
+        switch (ret) {
+            case JPEG_SUSPENDED: 
+                // suspended due to lack of data
+                throw ParserException(_("lack of data during JPEG "
+                            "header parsing"));
                 break;
-            case JPEG_HEADER_OK: // Found valid image datastream
+            case JPEG_HEADER_OK: 
+                // Found valid image datastream
                 break;
-            case JPEG_HEADER_TABLES_ONLY: // Found valid table-specs-only datastream
+            case JPEG_HEADER_TABLES_ONLY: 
+                // Found valid table-specs-only datastream
                 break;
             default:
-                log_debug(_("unexpected: jpeg_read_header returned %d [%s:%d]"),
+                log_error(_("unexpected: jpeg_read_header returned %d [%s:%d]"),
                         ret, __FILE__, __LINE__);
                 break;
         }
     }
 
-    if (_errorOccurred)
-    {
+    if (_errorOccurred) {
         std::stringstream ss;
         ss << _("Internal jpeg error during header parsing: ") << _errorOccurred;
         throw ParserException(ss.str());
@@ -363,8 +341,7 @@ JpegImageInput::read()
 
     jpeg_start_decompress(&m_cinfo);
 
-    if (_errorOccurred)
-    {
+    if (_errorOccurred) {
         std::stringstream ss;
         ss << _("Internal jpeg error during decompression: ") << _errorOccurred;
         throw ParserException(ss.str());
@@ -375,22 +352,20 @@ JpegImageInput::read()
     // Until this point the type should be GNASH_IMAGE_INVALID.
     // It's possible to create transparent JPEG data by merging an
     // alpha channel, but that is handled explicitly elsewhere.
-    _type = GNASH_IMAGE_RGB;
+    _type = TYPE_RGB;
 }
 
 
 void
-JpegImageInput::finishImage()
+JpegInput::finishImage()
 {
-    if ( setjmp(_jmpBuf) )
-    {
+    if (setjmp(_jmpBuf)) {
         std::stringstream ss;
         ss << _("Internal jpeg error: ") << _errorOccurred;
         throw ParserException(ss.str());
     }
 
-    if (_compressorOpened)
-    {
+    if (_compressorOpened) {
         jpeg_finish_decompress(&m_cinfo);
         _compressorOpened = false;
     }
@@ -399,7 +374,7 @@ JpegImageInput::finishImage()
 
 // Return the height of the image.  Take the data from our m_cinfo struct.
 size_t
-JpegImageInput::getHeight() const
+JpegInput::getHeight() const
 {
     assert(_compressorOpened);
     return m_cinfo.output_height;
@@ -408,7 +383,7 @@ JpegImageInput::getHeight() const
 
 // Return the width of the image.  Take the data from our m_cinfo struct.
 size_t
-JpegImageInput::getWidth() const
+JpegInput::getWidth() const
 {
     assert(_compressorOpened);
     return m_cinfo.output_width;
@@ -416,7 +391,7 @@ JpegImageInput::getWidth() const
 
 
 size_t
-JpegImageInput::getComponents() const
+JpegInput::getComponents() const
 {
     assert(_compressorOpened);
     return m_cinfo.output_components;
@@ -424,22 +399,26 @@ JpegImageInput::getComponents() const
 
 
 void
-JpegImageInput::readScanline(unsigned char* rgb_data)
+JpegInput::readScanline(unsigned char* rgb_data)
 {
     assert(_compressorOpened);
-
     assert(m_cinfo.output_scanline < m_cinfo.output_height);
-    int    lines_read = jpeg_read_scanlines(&m_cinfo, &rgb_data, 1);
-    assert(lines_read == 1);
-    lines_read = lines_read;    // avoid warning in NDEBUG
+
+    // C and its unsigned variables...
+    const int toRead = 1;
+    const int lines_read = jpeg_read_scanlines(&m_cinfo, &rgb_data, toRead);
+
+    // This happens in real cases.
+    if (lines_read != toRead) {
+        throw ParserException("Could not read JPEG scanline");
+    }
+
     // Expand grayscale to RGB
-    if (m_cinfo.out_color_space == JCS_GRAYSCALE)
-    {
+    if (m_cinfo.out_color_space == JCS_GRAYSCALE) {
         size_t w = getWidth();
         unsigned char* src = rgb_data + w - 1;
         unsigned char* dst = rgb_data + (w * 3) - 1;
-        for (;  w;  w--, src--)
-        {
+        for (;  w;  w--, src--) {
             *dst-- = *src;
             *dst-- = *src;
             *dst-- = *src;
@@ -449,23 +428,24 @@ JpegImageInput::readScanline(unsigned char* rgb_data)
 
 
 void
-JpegImageInput::errorOccurred(const char* msg)
+JpegInput::errorOccurred(const char* msg)
 {
-    log_debug("Long jump: banzaaaaaai!");
-    _errorOccurred = msg;
-
-    // Mark the compressor as closed so we can open another image
-    // with this instance. We should throw on any errors, so there
-    // should be no further activity on the current image.
-    if (_compressorOpened) _compressorOpened = false;
-    std::longjmp(_jmpBuf, 1);
+	log_error("Long jump: banzaaaaaai!");
+	
+	_errorOccurred = msg;
+	
+	// Mark the compressor as closed so we can open another image
+	// with this instance. We should throw on any errors, so there
+	// should be no further activity on the current image.
+	if (_compressorOpened) _compressorOpened = false;
+	std::longjmp(_jmpBuf, 1);
 }
 
-std::auto_ptr<GnashImage>
-JpegImageInput::readSWFJpeg2WithTables(JpegImageInput& loader)
 // Create and read a new image, using a input object that
 // already has tables loaded.  The IJG documentation describes
 // this as "abbreviated" format.
+std::auto_ptr<GnashImage>
+JpegInput::readSWFJpeg2WithTables(JpegInput& loader)
 {
 
     loader.read();
@@ -474,7 +454,7 @@ JpegImageInput::readSWFJpeg2WithTables(JpegImageInput& loader)
             new ImageRGB(loader.getWidth(), loader.getHeight()));
 
     for (size_t y = 0, height = loader.getHeight(); y < height; y++) {
-        loader.readScanline(im->scanline(y));
+        loader.readScanline(scanline(*im, y));
     }
 
     loader.finishImage();
@@ -489,7 +469,8 @@ JpegImageInput::readSWFJpeg2WithTables(JpegImageInput& loader)
 class rw_dest_IOChannel
 {
 public:
-    struct jpeg_destination_mgr    m_pub;    /* public fields */
+
+    struct jpeg_destination_mgr m_pub; 
 
     /// Constructor. 
     //
@@ -514,7 +495,7 @@ public:
 
     static void init_destination(j_compress_ptr cinfo)
     {
-        rw_dest_IOChannel*    dest = (rw_dest_IOChannel*) cinfo->dest;
+        rw_dest_IOChannel* dest = (rw_dest_IOChannel*) cinfo->dest;
         assert(dest);
 
         dest->m_pub.next_output_byte = dest->m_buffer;
@@ -529,15 +510,15 @@ public:
     }
 
     /// Write the output buffer into the stream.
-    static jpeg_bool_t empty_output_buffer(j_compress_ptr cinfo)
+    static boolean empty_output_buffer(j_compress_ptr cinfo)
     {
-        rw_dest_IOChannel*    dest = (rw_dest_IOChannel*) cinfo->dest;
+        rw_dest_IOChannel* dest = (rw_dest_IOChannel*) cinfo->dest;
         assert(dest);
 
-        if (dest->m_out_stream.write(dest->m_buffer, IO_BUF_SIZE) != IO_BUF_SIZE)
-        {
+        if (dest->m_out_stream.write(dest->m_buffer, IO_BUF_SIZE)
+                != IO_BUF_SIZE) {
             // Error.
-            log_error(_("jpeg::rw_dest_IOChannel couldn't write data."));
+            log_error(_("rw_dest_IOChannel couldn't write data."));
             return false;
         }
 
@@ -562,7 +543,7 @@ public:
             if (dest->m_out_stream.write(dest->m_buffer, datacount) != datacount)
             {
                 // Error.
-                log_error(_("jpeg::rw_dest_IOChannel::term_destination "
+                log_error(_("rw_dest_IOChannel::term_destination "
                             "couldn't write data."));
             }
         }
@@ -574,7 +555,7 @@ public:
 
 private:    
 
-    // Source stream, owned in this context by JpegImageInput
+    // Source stream, owned in this context by JpegInput
     IOChannel& m_out_stream;    
 
     JOCTET m_buffer[IO_BUF_SIZE];        /* start of buffer */
@@ -582,9 +563,10 @@ private:
 };
 
 
-JpegImageOutput::JpegImageOutput(boost::shared_ptr<IOChannel> out, size_t width, size_t height, int quality)
+JpegOutput::JpegOutput(boost::shared_ptr<IOChannel> out, size_t width,
+        size_t height, int quality)
     :
-    ImageOutput(out, width, height)
+    Output(out, width, height)
 {
     m_cinfo.err = jpeg_std_error(&m_jerr);
 
@@ -603,7 +585,7 @@ JpegImageOutput::JpegImageOutput(boost::shared_ptr<IOChannel> out, size_t width,
 }
 
 
-JpegImageOutput::~JpegImageOutput()
+JpegOutput::~JpegOutput()
 {
     jpeg_finish_compress(&m_cinfo);
     jpeg_destroy_compress(&m_cinfo);
@@ -611,28 +593,44 @@ JpegImageOutput::~JpegImageOutput()
 
 
 void
-JpegImageOutput::writeImageRGB(const unsigned char* rgbData)
+JpegOutput::writeImageRGB(const unsigned char* rgbData)
 {
     // RGB...
     const size_t components = 3;
 
-    for (size_t y = 0; y < _height; ++y)
-    {
+    for (size_t y = 0; y < _height; ++y) {
         const unsigned char* ypos = &rgbData[y * _width * components];
-
         // JPEG needs non-const data.
         jpeg_write_scanlines(&m_cinfo, const_cast<unsigned char**>(&ypos), 1);
     }
 }
 
-
-std::auto_ptr<ImageOutput>
-JpegImageOutput::create(boost::shared_ptr<IOChannel> out, size_t width, size_t height, int quality)
+void
+JpegOutput::writeImageRGBA(const unsigned char* rgbaData)
 {
-    std::auto_ptr<ImageOutput> outChannel(new JpegImageOutput(out, width, height, quality));
+    const size_t components = 3;
+    const size_t size = _width * _height;
+
+    boost::scoped_array<unsigned char> data(
+            new unsigned char[size * components]);
+
+    for (size_t pixel = 0; pixel < size; ++pixel) {
+        data[pixel * 3] = rgbaData[pixel * 4];
+        data[pixel * 3 + 1] = rgbaData[pixel * 4 + 1];
+        data[pixel * 3 + 2] = rgbaData[pixel * 4 + 2];
+    }
+    writeImageRGB(data.get());
+}
+
+std::auto_ptr<Output>
+JpegOutput::create(boost::shared_ptr<IOChannel> o, size_t width, size_t height,
+        int quality)
+{
+    std::auto_ptr<Output> outChannel(new JpegOutput(o, width, height, quality));
     return outChannel;
 }
 
+} // namespace image
 } // namespace gnash
 
 
