@@ -1,5 +1,5 @@
 //
-//   Copyright (C) 2008, 2009 Free Software Foundation, Inc.
+//   Copyright (C) 2008, 2009, 2010, 2011, 2012 Free Software Foundation, Inc.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -30,7 +30,11 @@
 
 #include <sys/time.h>
 
-#ifdef _WIN32
+#ifdef HAVE_PTHREADS
+#include <pthread.h>
+#endif
+
+#if defined WIN32 && !defined(HAVE_STRUCT_TIMESPEC)
 struct timespec {
 	time_t	tv_sec; 	/* seconds */
 	long	tv_nsec;	/* nanoseconds */
