@@ -1,6 +1,6 @@
 // 
-//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010 Free Software
-//   Foundation, Inc
+//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -22,7 +22,6 @@
 
 #include "dsodefs.h"
 
-#include <string>
 
 
 namespace gnash {
@@ -32,8 +31,7 @@ class IOChannel;
 /// Code to use volatile (non-back-seekable) streams as IOChannel
 /// objects (which are seekable by definition) by storing read bytes
 /// in a temporary file.
-namespace noseek_fd_adapter
-{
+namespace noseek_fd_adapter {
 
 /// \brief
 /// Returns a read-only IOChannel that fetches data
@@ -44,7 +42,7 @@ namespace noseek_fd_adapter
 /// Specify a cachefilename if you want to be able to access
 /// the full cache after deletion of the returned IOChannel.
 ///
-DSOEXPORT IOChannel* make_stream(int fd, const char* cachefilename=NULL);
+DSOEXPORT IOChannel* make_stream(int fd, const char* cachefilename = 0);
 
 } // namespace gnash::noseek_fd_adapter
 } // namespace gnash
