@@ -1,7 +1,7 @@
 // Button.cpp:  Mouse-sensitive buttons, for Gnash.
 // 
-//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010,
-//   2011 Free Software Foundation, Inc
+//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -26,8 +26,8 @@
 
 #include <boost/bind.hpp>
 #include <utility>
+#include <functional>
 
-#include "smart_ptr.h" 
 #include "DefineButtonTag.h"
 #include "as_value.h"
 #include "Button.h"
@@ -205,7 +205,8 @@ private:
     as_environment& _env;
 };
 
-class ButtonActionPusher {
+class ButtonActionPusher
+{
 public:
     ButtonActionPusher(movie_root& mr, DisplayObject* this_ptr)
         :
@@ -295,17 +296,10 @@ Button::Button(as_object* object, const SWF::DefineButtonTag* def,
     _def(def)
 {
     assert(object);
-
-    // check up presence Key events
-    if (_def->hasKeyPressHandler()) {
-        stage().add_key_listener(this);
-    }
-
 }
 
 Button::~Button()
 {
-    stage().remove_key_listener(this);
 }
 
 bool
@@ -341,26 +335,21 @@ Button::isEnabled()
 
 
 void
-Button::notifyEvent(const event_id& id)
+Button::keyPress(key::code c)
 {
     if (unloaded()) {
-        // We dont' respond to events while unloaded
+        // We don't respond to events while unloaded
         // See bug #22982
         return; 
     }
 
-    // We only respond keypress events
-    if ( id.id() != event_id::KEY_PRESS ) return;
-
-    // We only respond to valid key code (should we assert here?)
-    if ( id.keyCode() == key::INVALID ) return;
-
     ButtonActionPusher xec(stage(), this); 
-    _def->forEachTrigger(id, xec);
+    _def->forEachTrigger(event_id(event_id::KEY_PRESS, c), xec);
 }
 
 bool
-Button::handleFocus() {
+Button::handleFocus()
+{
     /// Nothing to do, but can receive focus.
     return false;
 }
@@ -455,11 +444,8 @@ Button::topmostMouseEntity(boost::int32_t x, boost::int32_t y)
 void
 Button::mouseEvent(const event_id& event)
 {
-    if ( unloaded() )
-    {
+    if (unloaded()) {
         // We don't respond to events while unloaded. See bug #22982.
-        log_debug("Button %s received %s button event while unloaded: ignored",
-            getTarget(), event);
         return;
     }
 
@@ -537,7 +523,7 @@ Button::mouseEvent(const event_id& event)
         if (!bs.sample) break;
 
         if (bs.soundInfo.stopPlayback) {
-            s->stop_sound(bs.sample->m_sound_handler_id);
+            s->stopEventSound(bs.sample->m_sound_handler_id);
         }
         else {
             const SWF::SoundInfoRecord& sinfo = bs.soundInfo;
@@ -696,7 +682,8 @@ Button::set_current_state(MouseState new_state)
                     int oldDepth = oldch->get_depth();
                     int newDepth = DisplayObject::removedDepthOffset - oldDepth;
 #ifdef GNASH_DEBUG_BUTTON_DISPLAYLIST
-                    log_debug("Removed button record shifted from depth %d to depth %d", oldDepth, newDepth);
+                    log_debug("Removed button record shifted from depth %d to depth %d",
+			      oldDepth, newDepth);
 #endif
                     oldch->set_depth(newDepth);
                 }
@@ -734,7 +721,7 @@ Button::set_current_state(MouseState new_state)
 #endif
 
     // Remember current state
-    _mouseState=new_state;
+    _mouseState = new_state;
      
 }
 
@@ -763,8 +750,9 @@ Button::getBounds() const
     typedef std::vector<const DisplayObject*> Chars;
     Chars actChars;
     getActiveCharacters(actChars);
-    for(Chars::const_iterator i=actChars.begin(),e=actChars.end(); i!=e; ++i)
-    {
+    for (Chars::const_iterator i = actChars.begin(), e = actChars.end();
+            i != e; ++i) {
+
         const DisplayObject* ch = *i;
         // Child bounds need be transformed in our coordinate space
         SWFRect lclBounds = ch->getBounds();
@@ -797,8 +785,8 @@ Button::construct(as_object* initObj)
     // (see misc-ming.all/attachMovieTest.swf).
     if (initObj) {
         IF_VERBOSE_ASCODING_ERRORS(
-            log_aserror("Button placed with an init object. This will "
-                "be ignored.");
+		log_aserror(_("Button placed with an init object. This will "
+			      "be ignored."));
         );
     }
 
@@ -844,6 +832,12 @@ Button::construct(as_object* initObj)
 
     // There is no INITIALIZE/CONSTRUCT/LOAD/ENTERFRAME/UNLOAD event 
     // for Buttons
+
+    // Register key events.
+    if (_def->hasKeyPressHandler()) {
+        stage().registerButton(this);
+    }
+
 }
 
 void
@@ -867,7 +861,6 @@ Button::markOwnResources() const
 bool
 Button::unloadChildren()
 {
-
     bool childsHaveUnload = false;
 
     // We need to unload all children, or the global instance list
@@ -894,6 +887,7 @@ Button::unloadChildren()
 void
 Button::destroy()
 {
+    stage().removeButton(this);
 
     for (DisplayObjects::iterator i = _stateCharacters.begin(),
             e=_stateCharacters.end(); i != e; ++i) {
@@ -919,19 +913,13 @@ Button::getDefinitionVersion() const
     return _def->getSWFVersion();
 }
 
-static as_value
-button_ctor(const fn_call& /*fn*/)
-{
-    return as_value();
-}
-
 void
 button_class_init(as_object& global, const ObjectURI& uri)
 {
     // This is going to be the global Button "class"/"function"
     Global_as& gl = getGlobal(global);
     as_object* proto = createObject(gl);
-    as_object* cl = gl.createClass(&button_ctor, proto);
+    as_object* cl = gl.createClass(emptyFunction, proto);
     attachButtonInterface(*proto);
 
     // Register _global.MovieClip
@@ -962,14 +950,20 @@ Button::getMovieInfo(InfoTree& tr, InfoTree::iterator it)
     getActiveCharacters(actChars, true);
     std::sort(actChars.begin(), actChars.end(), charDepthLessThen);
 
-    os << actChars.size() << " active DisplayObjects for state " <<
-        mouseStateName(_mouseState);
-    InfoTree::iterator localIter = tr.append_child(selfIt,
-            std::make_pair(_("Button state"), os.str()));
-
     os.str("");
     os << std::boolalpha << isEnabled();
-    localIter = tr.append_child(selfIt, std::make_pair(_("Enabled"), os.str()));
+    InfoTree::iterator localIter = tr.append_child(selfIt,
+            std::make_pair(_("Enabled"), os.str()));
+
+    os.str("");
+    os << _mouseState;
+    localIter = tr.append_child(selfIt,
+            std::make_pair(_("Button state"), os.str()));
+    
+    os.str("");
+    os << actChars.size();
+    localIter = tr.append_child(selfIt, std::make_pair(_("Action characters"),
+            os.str()));
 
     std::for_each(actChars.begin(), actChars.end(),
             boost::bind(&DisplayObject::getMovieInfo, _1, tr, localIter)); 
@@ -979,16 +973,15 @@ Button::getMovieInfo(InfoTree& tr, InfoTree::iterator it)
 }
 #endif
 
-const char*
-Button::mouseStateName(MouseState s)
+std::ostream&
+operator<<(std::ostream& o, const Button::MouseState& st)
 {
-    switch (s)
-    {
-        case MOUSESTATE_UP: return "UP";
-        case MOUSESTATE_DOWN: return "DOWN";
-        case MOUSESTATE_OVER: return "OVER";
-        case MOUSESTATE_HIT: return "HIT";
-        default: std::abort();
+    switch (st) {
+        case Button::MOUSESTATE_UP: return o << "UP";
+        case Button::MOUSESTATE_DOWN: return o << "DOWN";
+        case Button::MOUSESTATE_OVER: return o << "OVER";
+        case Button::MOUSESTATE_HIT: return o << "HIT";
+        default: return o << "Unknown state";
     }
 }
 
@@ -998,6 +991,7 @@ as_value
 button_blendMode(const fn_call& fn)
 {
     Button* obj = ensure<IsDisplayObject<Button> >(fn);
+    LOG_ONCE(log_unimpl(_("Button.blendMode")));
     UNUSED(obj);
     return as_value();
 }
@@ -1006,6 +1000,7 @@ as_value
 button_cacheAsBitmap(const fn_call& fn)
 {
     Button* obj = ensure<IsDisplayObject<Button> >(fn);
+    LOG_ONCE(log_unimpl(_("Button.cacheAsBitmap")));
     UNUSED(obj);
     return as_value();
 }
@@ -1014,6 +1009,7 @@ as_value
 button_filters(const fn_call& fn)
 {
     Button* obj = ensure<IsDisplayObject<Button> >(fn);
+    LOG_ONCE(log_unimpl(_("Button.filters")));
     UNUSED(obj);
     return as_value();
 }
@@ -1022,6 +1018,7 @@ as_value
 button_scale9Grid(const fn_call& fn)
 {
     Button* obj = ensure<IsDisplayObject<Button> >(fn);
+    LOG_ONCE(log_unimpl(_("Button.scale9Grid")));
     UNUSED(obj);
     return as_value();
 }
@@ -1030,6 +1027,7 @@ as_value
 button_getTabIndex(const fn_call& fn)
 {
     Button* obj = ensure<IsDisplayObject<Button> >(fn);
+    LOG_ONCE(log_unimpl(_("Button.getTabIndex")));
     UNUSED(obj);
     return as_value();
 }
@@ -1038,6 +1036,7 @@ as_value
 button_setTabIndex(const fn_call& fn)
 {
     Button* obj = ensure<IsDisplayObject<Button> >(fn);
+    LOG_ONCE(log_unimpl(_("Button.setTabIndex")));
     UNUSED(obj);
     return as_value();
 }
@@ -1045,9 +1044,10 @@ button_setTabIndex(const fn_call& fn)
 as_value
 button_getDepth(const fn_call& fn)
 {
-    Button* obj = ensure<IsDisplayObject<Button> >(fn);
-    UNUSED(obj);
-    return as_value();
+    // This does exactly the same as MovieClip.getDepth, but appears to be
+    // a separate function.
+    DisplayObject* obj = ensure<IsDisplayObject<Button> >(fn);
+    return as_value(obj->get_depth());
 }
 
 } // anonymous namespace
@@ -1058,5 +1058,5 @@ button_getDepth(const fn_call& fn)
 // mode: C++
 // c-basic-offset: 8 
 // tab-width: 8
-// indent-tabs-mode: t
+// indent-tabs-mode: nil
 // End:
