@@ -1,6 +1,7 @@
 // FillStyle.h: variant fill styles
 // 
-//   Copyright (C) 2007, 2008, 2009, 2010, 2011 Free Software Foundation, Inc.
+//   Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc.
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -39,12 +40,11 @@ namespace gnash {
 class GradientRecord
 {
 public:
-
     GradientRecord(boost::uint8_t ratio, const rgba& color)
         :
         ratio(ratio),
         color(color)
-    {}
+    { }
     
     //data:
     boost::uint8_t ratio;
@@ -156,7 +156,7 @@ public:
 
     /// The type of GradientFill
     //
-    /// A Focal fill is a gradient fill with a focal point.
+    /// A Radial fill is a gradient fill with a focal point.
     enum Type {
         LINEAR,
         RADIAL
@@ -200,6 +200,10 @@ public:
         _gradients = recs;
     }
 
+    const GradientRecords &getRecords() const {
+        return _gradients;
+    }
+
     /// Get the number of records in this GradientFill
     size_t recordCount() const {
         return _gradients.size();
@@ -247,17 +251,17 @@ public:
     explicit SolidFill(const rgba& c)
         :
         _color(c)
-    {}
+    { }
 
     /// Copy a SolidFill.
     SolidFill(const SolidFill& other)
         :
         _color(other._color)
-    {}
+    { }
 
     /// Set this fill to a lerp of two other SolidFills.
     void setLerp(const SolidFill& a, const SolidFill& b, double ratio) {
-        _color.set_lerp(a.color(), b.color(), ratio);
+        _color = lerp(a.color(), b.color(), ratio);
     }
 
     /// Get the color of the fill.
@@ -290,7 +294,7 @@ public:
     FillStyle(const FillStyle& other)
         :
         fill(other.fill)
-    {}
+    { }
 
     Fill fill;
 
@@ -302,15 +306,27 @@ public:
 /// errors are caught by type-checking and will throw an unhandled exception.
 void setLerp(FillStyle& f, const FillStyle& a, const FillStyle& b, double t);
 
+/// Output operator for bitmap smoothing policy.
 DSOEXPORT std::ostream& operator<<(std::ostream& os,
         const BitmapFill::SmoothingPolicy& p);
 
+/// Output operator for FillStyles.
+std::ostream& operator<<(std::ostream& os, const FillStyle& fs);
+
+/// Output operator for GradientFill type.
+std::ostream& operator<<(std::ostream& o, GradientFill::Type t);
+
+/// Output operator for GradientFill spread mode.
+std::ostream& operator<<(std::ostream& o, GradientFill::SpreadMode t);
+
+/// Output operator for GradientFill interpolation mode.
+std::ostream& operator<<(std::ostream& o, GradientFill::InterpolationMode t);
+
 } // namespace gnash
 
-#endif 
-
+#endif
 
 // Local Variables:
 // mode: C++
-// indent-tabs-mode: t
+// indent-tabs-mode: nil
 // End:
