@@ -1,6 +1,6 @@
 // 
-//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010,
-//   2011 Free Software Foundation, Inc
+//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -29,13 +29,13 @@
 #include <boost/thread/barrier.hpp>
 
 #include "URL.h"
-#include "as_object.h" 
 #include "MovieClip.h" 
 
 // Forward declarations
 namespace gnash {
     class movie_root;
     class movie_definition;
+    class as_object;
 }
 
 namespace gnash {
