@@ -1,6 +1,6 @@
 // 
-//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010 Free Software
-//   Foundation, Inc
+//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -22,14 +22,16 @@
 
 namespace gnash {
 
-
-/// Destructor of ActiveRelay needs definition of movie_root.
 ActiveRelay::~ActiveRelay()
+{
+}
+
+void
+ActiveRelay::clean()
 {
     getRoot(*_owner).removeAdvanceCallback(this);
 }
 
-
 void
 ActiveRelay::setReachable()
 {
