@@ -1,7 +1,7 @@
 // StaticText.cpp:  StaticText DisplayObject implementation for Gnash.
 // 
-//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010 Free Software
-//   Foundation, Inc
+//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -20,9 +20,9 @@
 
 #include "StaticText.h"
 #include "swf/DefineTextTag.h"
+#include "log.h"
 
-namespace gnash
-{
+namespace gnash {
 
 StaticText*
 StaticText::getStaticText(std::vector<const SWF::TextRecord*>& to,
@@ -46,19 +46,20 @@ StaticText::setSelectionColor(boost::uint32_t color)
 }
 
 bool
-StaticText::pointInShape(boost::int32_t /*x*/, boost::int32_t /*y*/) const
+StaticText::pointInShape(boost::int32_t x, boost::int32_t y) const
 {
-    // TODO: this has never worked as it relied on the default
-    // pointTestLocal in DefinitionTag, which returned false. There are
-    // no tests for whether StaticText has a proper hit test.
-    return false;
+    // TODO: check actual point in shape, as tested 
+    //       in misc-ming.all/DefineTextTest.swf
+    LOG_ONCE(log_unimpl(_("StaticText::pointInShape")));
+    return pointInBounds(x, y);
 }
 
 
 void  
-StaticText::display(Renderer& renderer)
+StaticText::display(Renderer& renderer, const Transform& base)
 {
-    _def->display(renderer, *this);
+    const Transform xform = base * transform();
+    _def->display(renderer, xform);
     clear_invalidated();
 }
 
