@@ -1,7 +1,7 @@
 // Array_as.cpp:  ActionScript array class, for Gnash.
 // 
-//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010,
-//   2011 Free Software Foundation, Inc
+//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -26,7 +26,6 @@
 #include <boost/algorithm/string/case_conv.hpp>
 #include <boost/lexical_cast.hpp>
 
-#include "smart_ptr.h" 
 #include "as_value.h"
 #include "log.h"
 #include "NativeFunction.h" 
@@ -980,7 +979,7 @@ array_splice(const fn_call& fn)
     ObjectURI propPush = getURI(getVM(fn), NSV::PROP_PUSH);
     for (size_t i = 0; i < remove; ++i) {
         const ObjectURI& key = getKey(fn, start + i);
-        callMethod(ret, NSV::PROP_PUSH, getOwnProperty(*array, key));
+        callMethod(ret, propPush, getOwnProperty(*array, key));
     }
 
     // Shift elements in 'this' array by simple assignment, not delete
