@@ -1,6 +1,6 @@
 // Key_as.cpp:  ActionScript "Keyboard" class, for Gnash.
 //
-//   Copyright (C) 2009, 2010, 2011 Free Software Foundation, Inc.
+//   Copyright (C) 2009, 2010, 2011, 2012 Free Software Foundation, Inc.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -18,7 +18,6 @@
 //
 
 
-#include "smart_ptr.h" 
 #include "Key_as.h"
 #include "log.h"
 #include "fn_call.h"
@@ -38,7 +37,7 @@ namespace gnash {
 as_value
 key_is_accessible(const fn_call& /*fn*/)
 {
-    log_unimpl("Key.isAccessible");
+    log_unimpl(_("Key.isAccessible"));
     return as_value();
 }
 
@@ -77,7 +76,7 @@ key_is_down(const fn_call& fn)
     if (keycode < 0 || keycode >= key::KEYCOUNT) {
         // AS coding error !
         IF_VERBOSE_ASCODING_ERRORS(
-            log_aserror("Key.isKeyDown(%d): keycode out of range", keycode);
+            log_aserror(_("Key.isKeyDown(%d): keycode out of range"), keycode);
         );
         return as_value(false);
     }
@@ -95,7 +94,7 @@ key_is_down(const fn_call& fn)
 as_value   
 key_is_toggled(const fn_call& /* fn */)
 {
-    log_unimpl("Key.isToggled");
+    log_unimpl(_("Key.isToggled"));
     // @@ TODO
     return as_value(false);
 }
