@@ -1,7 +1,7 @@
 // LoadVars.cpp:  ActionScript "LoadVars" class (HTTP variables), for Gnash.
 // 
-//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010,
-//   2011 Free Software Foundation, Inc
+//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -24,7 +24,6 @@
 #include "log.h"
 #include "fn_call.h"
 #include "Global_as.h"
-#include "smart_ptr.h" 
 #include "NativeFunction.h" // need builtin_function
 #include "as_function.h" // for calling event handlers
 #include "as_value.h" // for setting up a fn_call
@@ -45,7 +44,6 @@ namespace {
 
     as_value loadvars_tostring(const fn_call& fn);
     as_value loadvars_ctor(const fn_call& fn);
-	as_value loadvars_onLoad(const fn_call& fn);
 	as_value loadvars_onData(const fn_call& fn);
 	void attachLoadVarsInterface(as_object& o);
 }
@@ -77,14 +75,13 @@ attachLoadVarsInterface(as_object& o)
 
     o.init_member("toString", gl.createFunction(loadvars_tostring), flags);
 	o.init_member("onData", gl.createFunction(loadvars_onData), flags);
-	o.init_member("onLoad", gl.createFunction(loadvars_onLoad), flags);
+	o.init_member("onLoad", gl.createFunction(emptyFunction), flags);
     o.init_member("contentType", "application/x-www-form-urlencoded", flags);
 }
 
 as_value
 loadvars_onData(const fn_call& fn)
 {
-
 	as_object* thisPtr = fn.this_ptr;
 	if (!thisPtr) return as_value();
 
@@ -110,14 +107,6 @@ loadvars_onData(const fn_call& fn)
 	return as_value();
 }
 
-as_value
-loadvars_onLoad(const fn_call& /*fn*/)
-{
-	//GNASH_REPORT_FUNCTION;
-	return as_value();
-}
-
-
 as_value
 loadvars_tostring(const fn_call& fn)
 {
@@ -153,7 +142,7 @@ loadvars_ctor(const fn_call& fn)
         if (fn.nargs) {
             std::ostringstream ss;
             fn.dump_args(ss);
-            log_aserror("new LoadVars(%s) - arguments discarded",
+            log_aserror(_("new LoadVars(%s) - arguments discarded"),
                 ss.str());
         }
     );
