@@ -1,7 +1,7 @@
 // Object.cpp:  Implementation of ActionScript Object class, for Gnash.
 // 
-//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010,
-//   2011 Free Software Foundation, Inc
+//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -18,24 +18,24 @@
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 //
 
+#include "Object.h"
+
+#include <string>
+#include <sstream>
+
 #include "Movie.h"
 #include "DisplayObject.h"
-#include "smart_ptr.h"
 #include "fn_call.h"
-#include "as_object.h" // for inheritance
+#include "as_object.h" 
 #include "NativeFunction.h" 
 #include "movie_definition.h" 
 #include "sprite_definition.h"
 #include "VM.h" 
 #include "namedStrings.h" // for NSV::PROP_TO_STRING
 #include "Global_as.h"
-#include "Object.h"
-
+#include "movie_root.h"
 #include "log.h"
 
-#include <string>
-#include <sstream>
-
 namespace gnash {
 
 // Forward declarations
@@ -267,8 +267,7 @@ object_registerClass(const fn_call& fn)
     }
 
     const std::string& symbolid = fn.arg(0).to_string();
-    if (symbolid.empty())
-    {
+    if (symbolid.empty()) {
         IF_VERBOSE_ASCODING_ERRORS(
             std::stringstream ss;
             fn.dump_args(ss);
@@ -296,8 +295,8 @@ object_registerClass(const fn_call& fn)
     // https://savannah.gnu.org/bugs/index.php?23130
     DisplayObject* tgt = fn.env().target();
     if (!tgt) {
-        log_error("current environment has no target, wouldn't know "
-                "where to look for symbol required for registerClass"); 
+        log_error(_("current environment has no target, wouldn't know "
+                    "where to look for symbol required for registerClass"));
         return as_value(false);
     }
 
@@ -311,9 +310,9 @@ object_registerClass(const fn_call& fn)
 
     if (!d) {
         IF_VERBOSE_ASCODING_ERRORS(
-            log_aserror(_("Object.registerClass(%s, %s): "
-                "can't find exported symbol"),
-                symbolid, typeName(theclass));
+            log_aserror(_("Object.registerClass('%s', %s): "
+                "can't find exported symbol (id: %d)"),
+                symbolid, typeName(theclass), id);
             );
         return as_value(false);
     }
@@ -332,7 +331,8 @@ object_registerClass(const fn_call& fn)
         return as_value(false);
     }
 
-    exp_clipdef->registerClass(theclass);
+    movie_root& mr = getRoot(fn);
+    mr.registerClass(exp_clipdef, theclass);
     return as_value(true);
 }
 
@@ -368,12 +368,13 @@ object_isPropertyEnumerable(const fn_call& fn)
 {
     as_object* obj = ensure<ValidThis>(fn);
 
-    if (fn.nargs < 1) {
-        IF_VERBOSE_ASCODING_ERRORS(
-        log_aserror(_("Object.isPropertyEnumerable() requires one arg"));
-        );
-        return as_value();
+    if (!fn.nargs) {
+         IF_VERBOSE_ASCODING_ERRORS(
+            log_aserror(_("Object.isPropertyEnumerable() requires one arg"));
+         );
+        return as_value(false);
     }
+
     const as_value& arg = fn.arg(0);
     const std::string& propname = arg.to_string();
     if (arg.is_undefined() || propname.empty()) {
@@ -401,7 +402,7 @@ object_isPrototypeOf(const fn_call& fn)
 
     if (fn.nargs < 1) {
         IF_VERBOSE_ASCODING_ERRORS(
-        log_aserror(_("Object.isPrototypeOf() requires one arg"));
+            log_aserror(_("Object.isPrototypeOf() requires one arg"));
         );
         return as_value(false); 
     }
@@ -425,11 +426,10 @@ object_watch(const fn_call& fn)
 {
     as_object* obj = ensure<ValidThis>(fn);
 
-    if ( fn.nargs < 2 )
-    {
+    if (fn.nargs < 2) {
         IF_VERBOSE_ASCODING_ERRORS(
-        std::stringstream ss; fn.dump_args(ss);
-        log_aserror(_("Object.watch(%s): missing arguments"));
+            std::stringstream ss; fn.dump_args(ss);
+            log_aserror(_("Object.watch(%s): missing arguments"));
         );
         return as_value(false);
     }
@@ -437,11 +437,11 @@ object_watch(const fn_call& fn)
     const as_value& propval = fn.arg(0);
     const as_value& funcval = fn.arg(1);
 
-    if ( ! funcval.is_function() )
-    {
+    if (!funcval.is_function()) {
         IF_VERBOSE_ASCODING_ERRORS(
-        std::stringstream ss; fn.dump_args(ss);
-        log_aserror(_("Object.watch(%s): second argument is not a function"));
+            std::stringstream ss; fn.dump_args(ss);
+            log_aserror(_("Object.watch(%s): second argument is not a "
+                    "function"));
         );
         return as_value(false);
     }
@@ -451,7 +451,7 @@ object_watch(const fn_call& fn)
     std::string propname = propval.to_string();
     const ObjectURI& propkey = getURI(vm, propname);
     as_function* trig = funcval.to_function();
-    as_value cust; if ( fn.nargs > 2 ) cust = fn.arg(2);
+    const as_value cust = fn.nargs > 2 ? fn.arg(2) : as_value();
 
     return as_value(obj->watch(propkey, *trig, cust));
 }
