@@ -1,6 +1,6 @@
 // Sound_as.cpp:  ActionScript "Sound" class, for Gnash.
 //
-//   Copyright (C) 2009, 2010, 2011 Free Software Foundation, Inc.
+//   Copyright (C) 2009, 2010, 2011, 2012 Free Software Foundation, Inc.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -24,6 +24,7 @@
 #include <boost/scoped_array.hpp>
 #include <boost/thread/mutex.hpp>
 #include <boost/cstdint.hpp>
+#include <boost/optional.hpp>
 
 #include "RunResources.h"
 #include "log.h"
@@ -37,13 +38,14 @@
 #include "Global_as.h"
 #include "GnashException.h" // for ActionException
 #include "NativeFunction.h" // need builtin_function
-#include "smart_ptr.h" // for boost intrusive_ptr
 #include "VM.h"
 #include "namedStrings.h"
 #include "StreamProvider.h"
 #include "ObjectURI.h"
 #include "Relay.h"
+#include "Id3Info.h"
 
+//#define GNASH_DEBUG_SOUND_AS 1
 
 namespace gnash {
 
@@ -69,6 +71,9 @@ namespace {
     as_value sound_stop(const fn_call& fn);
     as_value checkPolicyFile_getset(const fn_call& fn);
     void attachSoundInterface(as_object& o);
+
+    /// If there is Id3 data, create an id3 member and call the onID3 function.
+    void handleId3Data(boost::optional<media::Id3Info> id3, as_object& sound);
 }
 
 /// A Sound object in ActionScript can control and play sound
@@ -235,7 +240,9 @@ private:
 
     /// Thread-safe setter for _soundCompleted
     void markSoundCompleted(bool completed);
-    
+
+    bool _soundLoaded;
+
     // Does this sound have a live input stream?
     bool isAttached() const {
         return (_inputStream);
@@ -258,7 +265,8 @@ Sound_as::Sound_as(as_object* owner)
     _leftOverSize(0),
     _inputStream(0),
     remainingLoops(0),
-    _soundCompleted(false)
+    _soundCompleted(false),
+    _soundLoaded(false)
 {
 }
 
@@ -284,9 +292,7 @@ sound_class_init(as_object& where, const ObjectURI& uri)
     proto->set_member_flags(NSV::PROP_CONSTRUCTOR, PropFlags::readOnly);
     proto->set_member_flags(NSV::PROP_uuPROTOuu, PropFlags::readOnly, 0);
 
-    // Register _global.String
     where.init_member(uri, cl, as_object::DefaultFlags);
-
 }
 
 void
@@ -334,17 +340,48 @@ Sound_as::update()
 {
     probeAudio();
 
-    VM& vm = getVM(owner());
-
     if (active()) {
-        owner().set_member(getURI(vm, "duration"), getDuration());
-        owner().set_member(getURI(vm, "position"), getPosition());
+        owner().set_member(NSV::PROP_DURATION, getDuration());
+        owner().set_member(NSV::PROP_POSITION, getPosition());
     }
 }
 
 void
 Sound_as::probeAudio()
 {
+    if ( ! externalSound ) {
+        // Only probe for sound complete
+        assert(_soundHandler);
+        assert(!_soundCompleted);
+        if (!_soundHandler->isSoundPlaying(soundId)) {
+            stopProbeTimer();
+            // dispatch onSoundComplete 
+            callMethod(&owner(), NSV::PROP_ON_SOUND_COMPLETE);
+        }
+        return;
+    }
+
+    if (!_mediaParser) return; // nothing to do here w/out a media parser
+
+    if ( ! _soundLoaded ) {
+#ifdef GNASH_DEBUG_SOUND_AS
+        log_debug("Probing audio for load");
+#endif
+        if (_mediaParser->parsingCompleted()) {
+
+            _soundLoaded = true;
+
+            if (!isStreaming) {
+                stopProbeTimer(); // will be re-started on Sound.start()
+            }
+            bool success = _mediaParser->getAudioInfo() != 0;
+            callMethod(&owner(), NSV::PROP_ON_LOAD, success);
+
+            // TODO: check if this should be called anyway.
+            if (success) handleId3Data(_mediaParser->getId3Info(), owner());
+        }
+        return; 
+    }
 
     if (isAttached()) {
 #ifdef GNASH_DEBUG_SOUND_AS
@@ -353,9 +390,12 @@ Sound_as::probeAudio()
 
         boost::mutex::scoped_lock lock(_soundCompletedMutex);
         if (_soundCompleted) {
-            // when _soundCompleted is true we're
-            // NOT attached !
-            _mediaParser.reset(); // no use for this anymore...
+            // when _soundCompleted is true we're NOT attached !
+            // MediaParser may be still needed,
+            // if this is a non-streaming sound
+            if ( isStreaming ) {
+                _mediaParser.reset(); // no use for this anymore...
+            }
             _inputStream = 0;
             _soundCompleted = false;
             stopProbeTimer();
@@ -364,13 +404,14 @@ Sound_as::probeAudio()
             callMethod(&owner(), NSV::PROP_ON_SOUND_COMPLETE);
         }
     }
-    else if (_mediaParser) {
+    else {
 #ifdef GNASH_DEBUG_SOUND_AS
         log_debug("Probing audio for start");
 #endif
 
         bool parsingCompleted = _mediaParser->parsingCompleted();
         try {
+            log_debug("Attaching aux streamer");
             _inputStream = attachAuxStreamerIfNeeded();
         } 
         catch (const MediaException& e) {
@@ -384,7 +425,7 @@ Sound_as::probeAudio()
 
         if ( ! _inputStream ) {
             if ( parsingCompleted ) {
-                log_debug("No audio in Sound input.");
+                log_error(_("No audio in Sound input."));
                 stopProbeTimer();
                 _mediaParser.reset(); // no use for this anymore...
             } else {
@@ -424,9 +465,8 @@ Sound_as::attachSound(int si, const std::string& name)
     soundId = si;
     soundName = name;
     
-    VM& vm = getVM(owner());
-    owner().set_member(getURI(vm, "duration"), getDuration());
-    owner().set_member(getURI(vm, "position"), getPosition());
+    owner().set_member(NSV::PROP_DURATION, getDuration());
+    owner().set_member(NSV::PROP_POSITION, getPosition());
 
 }
 
@@ -474,7 +514,7 @@ Sound_as::getVolume(int& volume)
         DisplayObject* ch = _attachedCharacter->get();
         if (! ch) {
             log_debug("Character attached to Sound was unloaded and "
-                    "couldn't rebind");
+                        "couldn't rebind");
             return false;
         }
         volume = ch->getVolume();
@@ -505,24 +545,28 @@ Sound_as::getVolume(int& volume)
 void
 Sound_as::loadSound(const std::string& file, bool streaming)
 {
-    if ( ! _mediaHandler || ! _soundHandler ) {
+    if (!_mediaHandler || !_soundHandler) {
         log_debug("No media or sound handlers, won't load any sound");
         return;
     }
 
     /// If we are already streaming stop doing so as we'll replace
     /// the media parser
-    if ( _inputStream ) {
+    if (_inputStream) {
         _soundHandler->unplugInputStream(_inputStream);
         _inputStream = 0;
     }
+    
+    /// Mark sound as not being loaded
+    // TODO: should we check for _soundLoaded == true?
+    _soundLoaded = false;
 
     /// Delete any media parser being used (make sure we have detached!)
     _mediaParser.reset();
 
     /// Start at offset 0, in case a previous ::start() call
     /// changed that.
-    _startTime=0;
+    _startTime = 0;
 
     const RunResources& rr = getRunResources(owner());
     URL url(file, rr.streamProvider().baseURL());
@@ -532,8 +576,11 @@ Sound_as::loadSound(const std::string& file, bool streaming)
     const StreamProvider& streamProvider = rr.streamProvider();
     std::auto_ptr<IOChannel> inputStream(streamProvider.getStream(url,
                 rcfile.saveStreamingMedia()));
-    if ( ! inputStream.get() ) {
-        log_error( _("Gnash could not open this url: %s"), url );
+
+    if (!inputStream.get()) {
+        log_error(_("Gnash could not open this URL: %s"), url );
+        // dispatch onLoad (false)
+        callMethod(&owner(), NSV::PROP_ON_LOAD, false);
         return;
     }
 
@@ -541,27 +588,21 @@ Sound_as::loadSound(const std::string& file, bool streaming)
     isStreaming = streaming;
 
     _mediaParser.reset(_mediaHandler->createMediaParser(inputStream).release());
-    if ( ! _mediaParser ) {
+    if (!_mediaParser) {
         log_error(_("Unable to create parser for Sound at %s"), url);
         // not necessarely correct, the stream might have been found...
+        // dispatch onLoad (false)
+        callMethod(&owner(), NSV::PROP_ON_LOAD, false);
         return;
     }
 
     // TODO: use global _soundbuftime
     _mediaParser->setBufferTime(60000); // one minute buffer... should be fine
 
-    if (isStreaming) {
-        startProbeTimer();
-    } 
-    else {
-        LOG_ONCE(log_unimpl("Non-streaming Sound.loadSound: will behave "
-                    "as a streaming one"));
-        // if not streaming, we'll probe on .start()
-    }
+    startProbeTimer();
 
-    VM& vm = getVM(owner());
-    owner().set_member(getURI(vm, "duration"), getDuration());
-    owner().set_member(getURI(vm, "position"), getPosition());
+    owner().set_member(NSV::PROP_DURATION, getDuration());
+    owner().set_member(NSV::PROP_POSITION, getPosition());
 }
 
 sound::InputStream*
@@ -632,23 +673,16 @@ void
 Sound_as::start(double secOff, int loops)
 {
     if ( ! _soundHandler ) {
-        log_error("No sound handler, nothing to start...");
+        log_error(_("No sound handler, nothing to start..."));
         return;
     }
 
     if (externalSound) {
         if ( ! _mediaParser ) {
-            log_error("No MediaParser initialized, can't start an external sound");
+            log_error(_("No MediaParser initialized, can't start an external sound"));
             return;
         }
 
-        if (secOff > 0) {
-            _startTime = secOff * 1000;
-            boost::uint32_t seekms = boost::uint32_t(secOff * 1000);
-            // TODO: boost::mutex::scoped_lock parserLock(_parserMutex);
-            _mediaParser->seek(seekms); // well, we try...
-        }
-
         if (isStreaming) {
             IF_VERBOSE_ASCODING_ERRORS(
             log_aserror(_("Sound.start() has no effect on a streaming Sound"));
@@ -656,13 +690,21 @@ Sound_as::start(double secOff, int loops)
             return;
         }
 
+        // Always seek as we might be called during or after some playing...
+        {
+            _startTime = secOff * 1000;
+            boost::uint32_t seekms = boost::uint32_t(secOff * 1000);
+            // TODO: boost::mutex::scoped_lock parserLock(_parserMutex);
+            bool seeked = _mediaParser->seek(seekms); // well, we try...
+            log_debug("Seeked MediaParser to %d, returned: %d", seekms, seeked);
+        }
+
+
         // Save how many loops to do (not when streaming)
         if (loops > 0) {
             remainingLoops = loops;
         }
 
-        // TODO: we should really be waiting for the sound to be fully
-        //       loaded before starting to play it (!isStreaming case)
         startProbeTimer();
 
     } else {
@@ -681,7 +723,8 @@ Sound_as::start(double secOff, int loops)
                     true, // allow multiple instances (checked)
                     inPoint
                     );
-        startProbeTimer();
+
+        startProbeTimer(); // to dispatch onSoundComplete
     }
 }
 
@@ -689,7 +732,7 @@ void
 Sound_as::stop(int si)
 {
     if ( ! _soundHandler ) {
-        log_error("No sound handler, nothing to stop...");
+        log_error(_("No sound handler, nothing to stop..."));
         return;
     }
 
@@ -701,10 +744,15 @@ Sound_as::stop(int si)
                 _inputStream=0;
             }
         } else {
-            _soundHandler->stop_sound(soundId);
+            if ( ! _attachedCharacter ) {
+                // See https://savannah.gnu.org/bugs/index.php?33888
+                _soundHandler->stopAllEventSounds();
+            } else {
+                _soundHandler->stopEventSound(soundId);
+            }
         }
     } else {
-        _soundHandler->stop_sound(si);
+        _soundHandler->stopEventSound(si);
     }
 }
 
@@ -712,7 +760,7 @@ size_t
 Sound_as::getDuration() const
 {
     if ( ! _soundHandler ) {
-        log_error("No sound handler, can't check duration...");
+        log_error(_("No sound handler, can't check duration..."));
         return 0;
     }
 
@@ -737,8 +785,8 @@ size_t
 Sound_as::getPosition() const
 {
     if (!_soundHandler) {
-        log_error("No sound handler, can't check position (we're "
-                "likely not playing anyway)...");
+        log_error(_("No sound handler, can't check position (we're "
+                    "likely not playing anyway)..."));
         return 0;
     }
 
@@ -804,7 +852,8 @@ Sound_as::getAudio(boost::int16_t* samples, unsigned int nSamples, bool& atEOF)
             _leftOverData.reset( _audioDecoder->decode(*frame, _leftOverSize) );
             _leftOverPtr = _leftOverData.get();
             if ( ! _leftOverData ) {
-                log_error("No samples decoded from input of %d bytes", frame->dataSize);
+                log_error(_("No samples decoded from input of %d bytes"),
+                          frame->dataSize);
                 continue;
             }
 
@@ -903,12 +952,11 @@ sound_new(const fn_call& fn)
         IF_VERBOSE_ASCODING_ERRORS(
             if (fn.nargs > 1) {
                 std::stringstream ss; fn.dump_args(ss);
-                log_aserror("new Sound(%d) : args after first one ignored",
+                log_aserror(_("new Sound(%d) : args after first one ignored"),
                     ss.str());
             }
         );
 
-
         const as_value& arg0 = fn.arg(0);
 
         if (!arg0.is_null() && !arg0.is_undefined()) {
@@ -918,9 +966,9 @@ sound_new(const fn_call& fn)
             IF_VERBOSE_ASCODING_ERRORS(
                 if (!ch) {
                     std::stringstream ss; fn.dump_args(ss);
-                    log_aserror("new Sound(%s) : first argument isn't null "
+                    log_aserror(_("new Sound(%s) : first argument isn't null "
                         "or undefined, and isn't a DisplayObject. "
-                        "We'll take as an invalid DisplayObject ref.",
+                                  "We'll take as an invalid DisplayObject ref."),
                         ss.str());
                 }
             );
@@ -986,7 +1034,7 @@ sound_stop(const fn_call& fn)
         sound_sample* ss = def->get_sound_sample(id);
         if (!ss) {
             IF_VERBOSE_MALFORMED_SWF(
-                log_swferror(_("Export '%s'is not a sound"), name);
+                log_swferror(_("Export '%s' is not a sound"), name);
                 );
             return as_value();
         }
@@ -1076,7 +1124,7 @@ sound_getbytestotal(const fn_call& fn)
 as_value
 sound_getpan(const fn_call& /*fn*/)
 {
-    LOG_ONCE( log_unimpl ("Sound.getPan()") );
+    LOG_ONCE(log_unimpl(_("Sound.getPan()")));
     return as_value();
 }
 
@@ -1091,7 +1139,7 @@ sound_getDuration(const fn_call& fn)
 as_value
 sound_setDuration(const fn_call& /*fn*/)
 {
-    LOG_ONCE( log_unimpl ("Sound.setDuration()") );
+    LOG_ONCE(log_unimpl(_("Sound.setDuration()")));
     return as_value();
 }
 
@@ -1106,14 +1154,14 @@ sound_getPosition(const fn_call& fn)
 as_value
 sound_setPosition(const fn_call& /*fn*/)
 {
-    LOG_ONCE( log_unimpl ("Sound.setPosition()") );
+    LOG_ONCE(log_unimpl(_("Sound.setPosition()")));
     return as_value();
 }
 
 as_value
 sound_gettransform(const fn_call& /*fn*/)
 {
-    LOG_ONCE( log_unimpl ("Sound.getTransform()") );
+    LOG_ONCE( log_unimpl(_("Sound.getTransform()")));
     return as_value();
 }
 
@@ -1125,8 +1173,8 @@ sound_getvolume(const fn_call& fn)
 
     if ( fn.nargs ) {
         IF_VERBOSE_ASCODING_ERRORS(
-        std::stringstream ss; fn.dump_args(ss);
-        log_aserror("Sound.getVolume(%s) : arguments ignored");
+            std::stringstream ss; fn.dump_args(ss);
+            log_aserror(_("Sound.getVolume(%s) : arguments ignored"));
         );
     }
 
@@ -1171,14 +1219,14 @@ sound_loadsound(const fn_call& fn)
 as_value
 sound_setpan(const fn_call& /*fn*/)
 {
-    LOG_ONCE( log_unimpl ("Sound.setPan()") );
+    LOG_ONCE(log_unimpl(_("Sound.setPan()")));
     return as_value();
 }
 
 as_value
 sound_settransform(const fn_call& /*fn*/)
 {
-    LOG_ONCE( log_unimpl ("Sound.setTransform()") );
+    LOG_ONCE(log_unimpl(_("Sound.setTransform()")));
     return as_value();
 }
 
@@ -1202,7 +1250,7 @@ sound_setvolume(const fn_call& fn)
 as_value
 checkPolicyFile_getset(const fn_call& /*fn*/)
 {
-    LOG_ONCE( log_unimpl ("Sound.checkPolicyFile") );
+    LOG_ONCE(log_unimpl(_("Sound.checkPolicyFile")));
     return as_value();
 }
 
@@ -1215,10 +1263,31 @@ sound_areSoundsInaccessible(const fn_call& /*fn*/)
     // 
     // naive test shows this always being undefined..
     //
-    LOG_ONCE( log_unimpl ("Sound.areSoundsInaccessible()") );
+    LOG_ONCE(log_unimpl(_("Sound.areSoundsInaccessible()")));
     return as_value();
 }
 
+void
+handleId3Data(boost::optional<media::Id3Info> id3, as_object& sound)
+{
+    if (!id3) return;
+    VM& vm = getVM(sound);
+
+    as_object* o = new as_object(getGlobal(sound));
+
+    // TODO: others.
+    if (id3->album) o->set_member(getURI(vm, "album"), *id3->album);
+    if (id3->year) o->set_member(getURI(vm, "year"), *id3->year);
+
+    // Add Sound.id3 member
+    const ObjectURI& id3prop = getURI(vm, "id3");
+    sound.set_member(id3prop, o);
+
+    // Notify onID3 function.
+    const ObjectURI& onID3 = getURI(vm, "onID3");
+    callMethod(&sound, onID3);
+}
+
 } // anonymous namespace 
 } // gnash namespace
 
