@@ -1,7 +1,7 @@
 // string.cpp:  ActionScript "String" class, for Gnash.
 //
-//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010,
-//   2011 Free Software Foundation, Inc
+//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -25,7 +25,6 @@
 #include <stdexcept>
 
 #include "SWFCtype.h"
-#include "smart_ptr.h"
 #include "fn_call.h"
 #include "Global_as.h"
 #include "as_object.h"
@@ -344,10 +343,12 @@ string_lastIndexOf(const fn_call& fn)
     
     std::string str;
     const int version = getStringVersioned(fn, val, str);
+    const std::wstring& wstr = utf8::decodeCanonicalString(str, version);
 
     if (!checkArgs(fn, 1, 2, "String.lastIndexOf()")) return as_value(-1);
 
-    const std::string& toFind = fn.arg(0).to_string(version);
+    const std::wstring& toFind = utf8::decodeCanonicalString(
+        fn.arg(0).to_string(version), version);
 
     int start = str.size();
 
@@ -359,7 +360,7 @@ string_lastIndexOf(const fn_call& fn)
         return as_value(-1);
     }
 
-    size_t found = str.rfind(toFind, start);
+    size_t found = wstr.rfind(toFind, start);
 
     if (found == std::string::npos) {
         return as_value(-1);
@@ -492,8 +493,8 @@ string_indexOf(const fn_call& fn)
         else {
             IF_VERBOSE_ASCODING_ERRORS(
                 if (start_arg < 0) {
-                    log_aserror("String.indexOf(%s, %s): second argument casts "
-                        "to invalid offset (%d)", tfarg, saval, start_arg);
+                    log_aserror(_("String.indexOf(%s, %s): second argument casts "
+                                  "to invalid offset (%d)"), tfarg, saval, start_arg);
                 }
             );
         }
@@ -752,7 +753,7 @@ getStringVersioned(const fn_call& fn, const as_value& val, std::string& str)
     ///       in most cases a null callerDef means the caller forgot to 
     ///       set the field (ie: a programmatic error)
     if (!fn.callerDef) {
-        log_error("No fn_call::callerDef in string function call");
+        log_error(_("No fn_call::callerDef in string function call"));
     }
 
     const int version = fn.callerDef ? fn.callerDef->get_version() :
