@@ -1,6 +1,6 @@
 // TextSnapshot_as.cpp:  ActionScript "TextSnapshot" class, for Gnash.
 //
-//   Copyright (C) 2009, 2010 Free Software Foundation, Inc.
+//   Copyright (C) 2009, 2010, 2011, 2012 Free Software Foundation, Inc.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -19,14 +19,15 @@
 
 
 #include "TextSnapshot_as.h"
-#include "GnashException.h" // for ActionException
+
+#include <boost/algorithm/string/compare.hpp>
+#include <boost/dynamic_bitset.hpp>
+#include <algorithm>
 
 #include "as_object.h" // for inheritance
 #include "log.h"
 #include "fn_call.h"
 #include "Global_as.h"
-#include "smart_ptr.h" // for boost intrusive_ptr
-#include "builtin_function.h" 
 #include "NativeFunction.h"
 #include "StaticText.h"
 #include "DisplayList.h"
@@ -35,11 +36,7 @@
 #include "swf/TextRecord.h"
 #include "RGBA.h"
 #include "GnashNumeric.h"
-
 #include "namedStrings.h"
-#include <boost/algorithm/string/compare.hpp>
-#include <boost/dynamic_bitset.hpp>
-#include <algorithm>
 
 namespace gnash {
 
@@ -240,7 +237,7 @@ TextSnapshot_as::getTextRunInfo(size_t start, size_t end, as_object& ri) const
             e = _textFields.end(); field != e; ++field) {
 
         const Records& rec = field->second;
-        const SWFMatrix& mat = field->first->getMatrix();
+        const SWFMatrix& mat = getMatrix(*field->first);
         const boost::dynamic_bitset<>& selected = field->first->getSelected();
 
         const std::string::size_type fieldStartIndex = pos;
@@ -282,13 +279,13 @@ TextSnapshot_as::getTextRunInfo(size_t start, size_t end, as_object& ri) const
                 el->init_member("height", twipsToPixels(tr->textHeight()));
 
                 const double factor = 65536.0;
-                el->init_member("matrix_a", mat.sx / factor);
-                el->init_member("matrix_b", mat.shx / factor);
-                el->init_member("matrix_c", mat.shy / factor);
-                el->init_member("matrix_d", mat.sy / factor);
+                el->init_member("matrix_a", mat.a() / factor);
+                el->init_member("matrix_b", mat.b() / factor);
+                el->init_member("matrix_c", mat.c() / factor);
+                el->init_member("matrix_d", mat.d() / factor);
 
-                const double xpos = twipsToPixels(mat.tx + x);
-                const double ypos = twipsToPixels(mat.ty + tr->yOffset());
+                const double xpos = twipsToPixels(mat.tx() + x);
+                const double ypos = twipsToPixels(mat.ty() + tr->yOffset());
                 el->init_member("matrix_tx", xpos);
                 el->init_member("matrix_ty", ypos);
 
@@ -499,8 +496,10 @@ textsnapshot_getTextRunInfo(const fn_call& fn)
         return as_value();
     }
 
-    size_t start = std::max<boost::int32_t>(0, toInt(fn.arg(0)));
-    size_t end = std::max<boost::int32_t>(start + 1, toInt(fn.arg(1)));
+    const size_t start = std::max<boost::int32_t>(0,
+            toInt(fn.arg(0), getVM(fn)));
+    const size_t end = std::max<boost::int32_t>(start + 1,
+            toInt(fn.arg(1), getVM(fn)));
 
     Global_as& gl = getGlobal(fn);
     as_object* ri = gl.createArray();
@@ -519,17 +518,17 @@ textsnapshot_findText(const fn_call& fn)
 
     if (fn.nargs != 3) {
         IF_VERBOSE_ASCODING_ERRORS(
-            log_aserror("TextSnapshot.findText() requires 3 arguments");
+            log_aserror(_("TextSnapshot.findText() requires 3 arguments"));
         );
         return as_value();
     }
 
-    boost::int32_t start = toInt(fn.arg(0));
+    boost::int32_t start = toInt(fn.arg(0), getVM(fn));
     const std::string& text = fn.arg(1).to_string();
 
     /// Yes, the pp is case-insensitive by default. We don't write
     /// functions like that here.
-    bool ignoreCase = !fn.arg(2).to_bool();
+    const bool ignoreCase = !toBool(fn.arg(2), getVM(fn));
 
     return ts->findText(start, text, ignoreCase);
 }
@@ -543,7 +542,7 @@ textsnapshot_getCount(const fn_call& fn)
 
     if (fn.nargs) {
         IF_VERBOSE_ASCODING_ERRORS(
-            log_aserror("TextSnapshot.getCount() takes no arguments");
+            log_aserror(_("TextSnapshot.getCount() takes no arguments"));
         );
         return as_value();
     }
@@ -563,8 +562,10 @@ textsnapshot_getSelected(const fn_call& fn)
         return as_value();
     }
 
-    size_t start = std::max<boost::int32_t>(0, toInt(fn.arg(0)));
-    size_t end = std::max<boost::int32_t>(start + 1, toInt(fn.arg(1)));
+    const size_t start = std::max<boost::int32_t>(0,
+            toInt(fn.arg(0), getVM(fn)));
+    const size_t end = std::max<boost::int32_t>(start + 1,
+            toInt(fn.arg(1), getVM(fn)));
 
     return as_value(ts->getSelected(start, end));
 }
@@ -581,7 +582,7 @@ textsnapshot_getSelectedText(const fn_call& fn)
         return as_value();
     }
 
-    bool newlines = fn.nargs ? fn.arg(0).to_bool() : false;
+    const bool newlines = fn.nargs ? toBool(fn.arg(0), getVM(fn)) : false;
 
     return as_value(ts->getSelectedText(newlines));
 }
@@ -597,15 +598,15 @@ textsnapshot_getText(const fn_call& fn)
     if (fn.nargs < 2 || fn.nargs > 3)
     {
         IF_VERBOSE_ASCODING_ERRORS(
-            log_aserror("TextSnapshot.getText requires exactly 2 arguments");
+            log_aserror(_("TextSnapshot.getText requires exactly 2 arguments"));
         );
         return as_value();
     }
 
-    boost::int32_t start = toInt(fn.arg(0));
-    boost::int32_t end = toInt(fn.arg(1));
+    const boost::int32_t start = toInt(fn.arg(0), getVM(fn));
+    const boost::int32_t end = toInt(fn.arg(1), getVM(fn));
 
-    const bool newline = (fn.nargs > 2) ? fn.arg(2).to_bool() : false;
+    const bool newline = (fn.nargs > 2) ? toBool(fn.arg(2), getVM(fn)) : false;
 
     return ts->getText(start, end, newline);
 
@@ -620,7 +621,7 @@ textsnapshot_hitTestTextNearPos(const fn_call& fn)
 
     if (!ts->valid()) return as_value();
 
-    log_unimpl (__FUNCTION__);
+    log_unimpl(__FUNCTION__);
     return as_value();
 }
 
@@ -632,7 +633,7 @@ textsnapshot_setSelectColor(const fn_call& fn)
     TextSnapshot_as* ts = ensure<ThisIsNative<TextSnapshot_as> >(fn);
     UNUSED(ts);
 
-    log_unimpl (__FUNCTION__);
+    log_unimpl(__FUNCTION__);
     return as_value();
 }
 
@@ -647,10 +648,12 @@ textsnapshot_setSelected(const fn_call& fn)
         return as_value();
     }
 
-    size_t start = std::max<boost::int32_t>(0, toInt(fn.arg(0)));
-    size_t end = std::max<boost::int32_t>(start, toInt(fn.arg(1)));
+    const size_t start = std::max<boost::int32_t>(0,
+            toInt(fn.arg(0), getVM(fn)));
+    const size_t end = std::max<boost::int32_t>(start,
+            toInt(fn.arg(1), getVM(fn)));
 
-    bool selected = (fn.nargs > 2) ? fn.arg(2).to_bool() : true;
+    const bool selected = (fn.nargs > 2) ? toBool(fn.arg(2), getVM(fn)) : true;
 
     ts->setSelected(start, end, selected);
 
