@@ -1,6 +1,6 @@
 // 
-//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010,
-//   2011 Free Software Foundation, Inc
+//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -22,7 +22,6 @@
 #include "SWFParser.h"
 #include "TagLoadersTable.h"
 #include "log.h"
-#include "smart_ptr.h"
 
 #include <iomanip>
 
@@ -88,7 +87,7 @@ SWFParser::read(std::streamsize bytes)
 
             if (_tag == SWF::SHOWFRAME) {
                 // show frame tag -- advance to the next frame.
-                IF_VERBOSE_PARSE(log_parse("SHOWFRAME tag"));
+                IF_VERBOSE_PARSE(log_parse(_("SHOWFRAME tag")));
                 _md->incrementLoadedFrames();
             }
             else if (tagLoaders.get(_tag, lf)) {
@@ -103,7 +102,7 @@ SWFParser::read(std::streamsize bytes)
                 IF_VERBOSE_PARSE(
                     std::ostringstream ss;
                     dumpTagBytes(_stream, ss);
-                    log_error("tag dump follows: %s", ss.str());
+                    log_error(_("tag dump follows: %s"), ss.str());
                 );
             }
 
