@@ -1,5 +1,6 @@
 // 
-//   Copyright (C) 2007, 2008, 2009, 2010, 2011 Free Software Foundation, Inc.
+//   Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc.
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -190,6 +191,7 @@ DefineEditTextTag::DefineEditTextTag(SWFStream& in, movie_definition& m,
 	_useOutlines(false),
 	_fontID(-1),
 	_textHeight(240),
+    _color(0, 0, 0, 255),
 	_maxChars(0),
 	_alignment(TextField::ALIGN_LEFT),
 	_leftMargin(0),
@@ -197,8 +199,6 @@ DefineEditTextTag::DefineEditTextTag(SWFStream& in, movie_definition& m,
 	_indent(0),
 	_leading(0)
 {
-	_color.set(0, 0, 0, 255);
-    
     // Parse the tag from the stream.
     read(in, m);
 }
