@@ -1,5 +1,6 @@
 // 
-//   Copyright (C) 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
+//   Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc.
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -61,12 +62,12 @@ public:
             throw ParserException("DoAction tag found in AS3 SWF!");
         }
         
-		DoActionTag* da = new DoActionTag(m);
+		boost::intrusive_ptr<DoActionTag> da(new DoActionTag(m));
 		da->read(in);
 
-		IF_VERBOSE_PARSE (
-		log_parse(_("tag %d: do_action_loader"), tag);
-		log_parse(_("-- actions in frame %d"), m.get_loading_frame());
+		IF_VERBOSE_PARSE(
+            log_parse(_("tag %d: do_action_loader"), tag);
+            log_parse(_("-- actions in frame %d"), m.get_loading_frame());
 		);
 
 		m.addControlTag(da); // ownership transferred
