@@ -1,5 +1,6 @@
 // 
-//   Copyright (C) 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
+//   Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc.
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -18,13 +19,13 @@
 #ifndef GNASH_SWF_SETBACKGROUNDCOLOR_TAG_H
 #define GNASH_SWF_SETBACKGROUNDCOLOR_TAG_H
 
-#include "ControlTag.h" // for inheritance
-#include "SWF.h" // for TagType definition
-#include "MovieClip.h" // for inlines (execute)
-#include "movie_definition.h" // for inlines (loader)
-#include "log.h" // for log_parse
-#include "RGBA.h" // for rgba class
-#include "GnashNumeric.h" // for frnd
+#include "ControlTag.h" 
+#include "TypesParser.h"
+#include "SWF.h" 
+#include "MovieClip.h" 
+#include "movie_definition.h" 
+#include "log.h" 
+#include "RGBA.h" 
 
 // Forward declarations
 namespace gnash {
@@ -55,7 +56,7 @@ private:
 	void read(SWFStream& in)
 	{
 		// may throw ParserException
-		m_color.read_rgb(in);
+		m_color = readRGB(in);
 
 		IF_VERBOSE_PARSE(
             log_parse(_("  SetBackgroundColor: %s"), m_color);
@@ -72,22 +73,15 @@ public:
 	/// Tag header is assumed to have been read already
 	///
 	/// Can throw ParserException on premature end of input stream
-	///
 	SetBackgroundColorTag(SWFStream& in)
-	{
+    {
 		read(in);
 	}
 
-	void execute(MovieClip* m, DisplayList& /*dlist*/) const
-	{
+	void executeState(MovieClip* m, DisplayList& /*dlist*/) const {
 		m->set_background_color(m_color);
 	}
 
-	void execute_state(MovieClip* m, DisplayList& dlist) const
-	{
-		execute(m, dlist);
-	}
-
 	/// Set background color tag loader (SWF::SETBACKGROUNDCOLOR)
 	static void loader(SWFStream& in, TagType tag, movie_definition& m, 
             const RunResources& /*r*/)
@@ -95,7 +89,7 @@ public:
 		assert(tag == SWF::SETBACKGROUNDCOLOR); // 9
 
 		// this one may throw, we'll let caller catch it
-		SetBackgroundColorTag* t = new SetBackgroundColorTag(in);
+		boost::intrusive_ptr<ControlTag> t(new SetBackgroundColorTag(in));
 		m.addControlTag(t); // takes ownership
 	}
 };
