@@ -1,6 +1,6 @@
 //
-//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010,
-//   2011 Free Software Foundation, Inc
+//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -19,18 +19,18 @@
 
 #include "ShapeRecord.h"
 
+#include <vector>
+
 #include "TypesParser.h"
+#include "utility.h"
 #include "SWF.h"
 #include "SWFStream.h"
 #include "movie_definition.h"
-#include "smart_ptr.h"
 #include "FillStyle.h"
 #include "Geometry.h"
 #include "GnashNumeric.h"
 #include "log.h"
 
-#include <vector>
-
 namespace gnash {
 namespace SWF {
 
@@ -100,10 +100,8 @@ public:
     const Edge& getNextEdge()
     {
         const Edge& ret = _paths[_currpath][_curredge];
-        if ( ++_curredge >= _paths[_currpath].size() )
-        {
-            if ( ++_currpath >= _paths.size() )
-            {
+        if ( ++_curredge >= _paths[_currpath].size() ) {
+            if ( ++_currpath >= _paths.size() ) {
                 // this is not really needed,
                 // but it's simpler to do so that
                 // to make next call fail or abort..
@@ -220,8 +218,7 @@ ShapeRecord::setLerp(const ShapeRecord& a, const ShapeRecord& b,
     // shape
     const Paths& paths1 = a.paths();
     const Paths& paths2 = b.paths();
-    for (size_t i = 0, k = 0, n = 0; i < _paths.size(); i++)
-    {
+    for (size_t i = 0, k = 0, n = 0; i < _paths.size(); i++) {
         Path& p = _paths[i];
         const Path& p1 = i < paths1.size() ? paths1[i] : empty_path;
         const Path& p2 = n < paths2.size() ? paths2[n] : empty_path;
@@ -236,8 +233,7 @@ ShapeRecord::setLerp(const ShapeRecord& a, const ShapeRecord& b,
         const size_t len = p1.size();
         p.m_edges.resize(len);
 
-        for (size_t j=0; j < p.size(); j++)
-        {
+        for (size_t j=0; j < p.size(); j++) {
             Edge& e = p[j];
             const Edge& e1 = j < p1.size() ? p1[j] : empty_edge;
 
@@ -271,7 +267,6 @@ ShapeRecord::read(SWFStream& in, SWF::TagType tag, movie_definition& m,
                             tag == SWF::DEFINESHAPE4_);
 
     if (styleInfo) {
-
         _bounds = readRect(in);
     
         IF_VERBOSE_PARSE(
@@ -282,6 +277,7 @@ ShapeRecord::read(SWFStream& in, SWF::TagType tag, movie_definition& m,
         // TODO: Store and use these. Unfinished.
         if (tag == SWF::DEFINESHAPE4 || tag == SWF::DEFINESHAPE4_) {
             const SWFRect tbound = readRect(in);
+            UNUSED(tbound);
             in.ensureBytes(1);
             static_cast<void>(in.read_u8());
             LOG_ONCE(log_unimpl("DEFINESHAPE4 edge boundaries and scales"));
@@ -291,8 +287,7 @@ ShapeRecord::read(SWFStream& in, SWF::TagType tag, movie_definition& m,
         readLineStyles(_lineStyles, in, tag, m, r);
     }
 
-    if (tag == SWF::DEFINEFONT || tag == SWF::DEFINEFONT2 )
-    {
+    if (tag == SWF::DEFINEFONT || tag == SWF::DEFINEFONT2 ) {
         assert(!styleInfo);
     }
     
@@ -307,8 +302,7 @@ ShapeRecord::read(SWFStream& in, SWF::TagType tag, movie_definition& m,
             tag, num_fill_bits, num_line_bits);
     );
     
-    if ( !num_fill_bits && !num_line_bits )
-    {
+    if ( !num_fill_bits && !num_line_bits ) {
         /// When reading font glyphs it happens to read 1 byte
         /// past end boundary of a glyph due to fill/line bits being
         /// zero.
@@ -324,8 +318,7 @@ ShapeRecord::read(SWFStream& in, SWF::TagType tag, movie_definition& m,
         ///
         ///
         if (tag == SWF::DEFINEFONT || tag == SWF::DEFINEFONT2 || 
-                tag == SWF::DEFINEFONT3)
-        {
+                tag == SWF::DEFINEFONT3) {
             log_debug("Skipping glyph read, being fill and line bits zero. "
                     "SWF tag is %d.", tag);
             return;
@@ -347,30 +340,24 @@ ShapeRecord::read(SWFStream& in, SWF::TagType tag, movie_definition& m,
 #define SHAPE_LOG 0
     
     // SHAPERECORDS
-    for (;;)
-    {
+    for (;;) {
         in.ensureBits(1);
         bool isEdgeRecord = in.read_bit();
-        if (!isEdgeRecord)
-        {
+        if (!isEdgeRecord) {
             // Parse the record.
             in.ensureBits(5);
             int flags = in.read_uint(5);
-            if (flags == SHAPE_END)
-            {  
+            if (flags == SHAPE_END) {  
                 // Store the current path if any.
-                if (! current_path.empty())
-                {
+                if (! current_path.empty()) {
                     _paths.push_back(current_path);
                     current_path.m_edges.resize(0);
                 }
                 break;
             }
-            if (flags & SHAPE_MOVE)
-            {  
+            if (flags & SHAPE_MOVE) {  
                 // Store the current path if any, and prepare a fresh one.
-                if (! current_path.empty())
-                {
+                if (! current_path.empty()) {
                     _paths.push_back(current_path);
                     current_path.m_edges.resize(0);
                 }
@@ -393,11 +380,9 @@ ShapeRecord::read(SWFStream& in, SWF::TagType tag, movie_definition& m,
                 );
 #endif
             }
-            if ((flags & SHAPE_FILLSTYLE0_CHANGE) && num_fill_bits > 0)
-            {
+            if ((flags & SHAPE_FILLSTYLE0_CHANGE) && num_fill_bits > 0) {
                 // FillStyle_0_change = 1;
-                if (! current_path.empty())
-                {
+                if (! current_path.empty()) {
                     _paths.push_back(current_path);
                     current_path.m_edges.resize(0);
                     current_path.ap.x = x;
@@ -405,15 +390,12 @@ ShapeRecord::read(SWFStream& in, SWF::TagType tag, movie_definition& m,
                 }
                 in.ensureBits(num_fill_bits);
                 unsigned style = in.read_uint(num_fill_bits);
-                if (style > 0)
-                {
+                if (style > 0) {
                     style += fill_base;
                 }
     
-                if (tag == SWF::DEFINEFONT || tag == SWF::DEFINEFONT2)
-                {
-                    if ( style > 1 )          // 0:hide 1:renderer
-                    {
+                if (tag == SWF::DEFINEFONT || tag == SWF::DEFINEFONT2) {
+                    if ( style > 1 ) {         // 0:hide 1:renderer
                         IF_VERBOSE_MALFORMED_SWF(
                              log_swferror(_("Invalid fill style %d in "
                                      "fillStyle0Change record for font tag "
@@ -421,12 +403,9 @@ ShapeRecord::read(SWFStream& in, SWF::TagType tag, movie_definition& m,
                         );
                         style = 0;
                     }
-                }
-                else
-                {
+                } else {
                     // 1-based index
-                    if ( style > _fillStyles.size() )
-                    {
+                    if ( style > _fillStyles.size() ) {
                         IF_VERBOSE_MALFORMED_SWF(
                              log_swferror(_("Invalid fill style %d in "
                                      "fillStyle0Change record - %d defined. "
@@ -444,11 +423,9 @@ ShapeRecord::read(SWFStream& in, SWF::TagType tag, movie_definition& m,
                 );
 #endif
             }
-            if ((flags & SHAPE_FILLSTYLE1_CHANGE) && num_fill_bits > 0)
-            {
+            if ((flags & SHAPE_FILLSTYLE1_CHANGE) && num_fill_bits > 0) {
                 // FillStyle_1_change = 1;
-                if (! current_path.empty())
-                {
+                if (! current_path.empty()) {
                     _paths.push_back(current_path);
                     current_path.m_edges.resize(0);
                     current_path.ap.x = x;
@@ -456,15 +433,12 @@ ShapeRecord::read(SWFStream& in, SWF::TagType tag, movie_definition& m,
                 }
                 in.ensureBits(num_fill_bits);
                 unsigned style = in.read_uint(num_fill_bits);
-                if (style > 0)
-                {
+                if (style > 0) {
                     style += fill_base;
                 }
     
-                if (tag == SWF::DEFINEFONT || tag == SWF::DEFINEFONT2)
-                {
-                    if ( style > 1 )          // 0:hide 1:renderer
-                    {
+                if (tag == SWF::DEFINEFONT || tag == SWF::DEFINEFONT2) {
+                    if ( style > 1 ) {          // 0:hide 1:renderer
                         IF_VERBOSE_MALFORMED_SWF(
                              log_swferror(_("Invalid fill style %d in "
                                      "fillStyle1Change record for font tag "
@@ -472,12 +446,9 @@ ShapeRecord::read(SWFStream& in, SWF::TagType tag, movie_definition& m,
                         );
                         style = 0;
                     }
-                }
-                else
-                {
+                } else {
                     // 1-based index
-                    if ( style > _fillStyles.size() )
-                    {
+                    if ( style > _fillStyles.size() ) {
                         IF_VERBOSE_MALFORMED_SWF(
                             log_swferror(_("Invalid fill style %d in "
                                     "fillStyle1Change record - %d defined. "
@@ -494,11 +465,9 @@ ShapeRecord::read(SWFStream& in, SWF::TagType tag, movie_definition& m,
                 );
 #endif
             }
-            if ((flags & SHAPE_LINESTYLE_CHANGE) && num_line_bits > 0)
-            {
+            if ((flags & SHAPE_LINESTYLE_CHANGE) && num_line_bits > 0) {
                 // line_style_change = 1;
-                if (! current_path.empty())
-                {
+                if (! current_path.empty()) {
                     _paths.push_back(current_path);
                     current_path.m_edges.resize(0);
                     current_path.ap.x = x;
@@ -506,14 +475,11 @@ ShapeRecord::read(SWFStream& in, SWF::TagType tag, movie_definition& m,
                 }
                 in.ensureBits(num_line_bits);
                 unsigned style = in.read_uint(num_line_bits);
-                if (style > 0)
-                {
+                if (style > 0) {
                     style += line_base;
                 }
-                if (tag == SWF::DEFINEFONT || tag == SWF::DEFINEFONT2)
-                {
-                    if ( style > 1 )          // 0:hide 1:renderer
-                    {
+                if (tag == SWF::DEFINEFONT || tag == SWF::DEFINEFONT2) {
+                    if ( style > 1 ) {         // 0:hide 1:renderer
                         IF_VERBOSE_MALFORMED_SWF(
                             log_swferror(_("Invalid line style %d in "
                                     "lineStyleChange record for font tag "
@@ -521,8 +487,7 @@ ShapeRecord::read(SWFStream& in, SWF::TagType tag, movie_definition& m,
                         );
                         style = 0;
                     }
-                }
-                else {
+                } else {
                     // 1-based index
                     if (style > _lineStyles.size()) {
                         IF_VERBOSE_MALFORMED_SWF(
@@ -541,10 +506,8 @@ ShapeRecord::read(SWFStream& in, SWF::TagType tag, movie_definition& m,
                 )
 #endif
             }
-            if (flags & SHAPE_HAS_NEW_STYLES)
-            {
-                if (!styleInfo)
-                {
+            if (flags & SHAPE_HAS_NEW_STYLES) {
+                if (!styleInfo) {
                     IF_VERBOSE_MALFORMED_SWF(
                          log_swferror("Unexpected HasNewStyle flag in tag "
                              "%d shape record", tag);
@@ -556,8 +519,7 @@ ShapeRecord::read(SWFStream& in, SWF::TagType tag, movie_definition& m,
                 );
     
                 // Store the current path if any.
-                if (! current_path.empty())
-                {
+                if (! current_path.empty()) {
                     _paths.push_back(current_path);
                     current_path.clear();
                 }
@@ -577,14 +539,11 @@ ShapeRecord::read(SWFStream& in, SWF::TagType tag, movie_definition& m,
                 num_fill_bits = in.read_uint(4);
                 num_line_bits = in.read_uint(4);
             }
-        }
-        else
-        {
+        } else {
             // EDGERECORD
             in.ensureBits(1);
             bool edge_flag = in.read_bit();
-            if (edge_flag == 0)
-            {
+            if (edge_flag == 0) {
                 in.ensureBits(4);
                 int num_bits = 2 + in.read_uint(4);
                 // curved edge
@@ -603,9 +562,7 @@ ShapeRecord::read(SWFStream& in, SWF::TagType tag, movie_definition& m,
                 current_path.m_edges.push_back(Edge(cx, cy, ax, ay));
                 x = ax;
                 y = ay;
-            }
-            else
-            {
+            } else {
                 // straight edge
                 in.ensureBits(5);
                 int num_bits = 2 + in.read_uint(4);
@@ -617,19 +574,14 @@ ShapeRecord::read(SWFStream& in, SWF::TagType tag, movie_definition& m,
                     in.ensureBits(2 * num_bits);
                     dx = in.read_sint(num_bits);
                     dy = in.read_sint(num_bits);
-                }
-                else
-                {
+                } else {
                     in.ensureBits(1);
                     bool vert_flag = in.read_bit();
-                    if (vert_flag == 0)
-                    {
+                    if (vert_flag == 0) {
                         // Horizontal line.
                         in.ensureBits(num_bits);
                         dx = in.read_sint(num_bits);
-                    }
-                    else
-                    {
+                    } else {
                         // Vertical line.
                         in.ensureBits(num_bits);
                         dy = in.read_sint(num_bits);
@@ -650,16 +602,14 @@ ShapeRecord::read(SWFStream& in, SWF::TagType tag, movie_definition& m,
         }
     }
     
-    if (!styleInfo)
-    {
+    if (!styleInfo) {
         // TODO: performance would be improved by computing
         //       the bounds as edges are parsed.
         computeBounds(_bounds, _paths, _lineStyles, m.get_version());
     }
 
 #ifdef GNASH_DEBUG_SHAPE_BOUNDS
-    else
-    {
+    else {
         SWFRect computedBounds;
         computeBounds(computedBounds, _paths, _lineStyles, m.get_version());
         if ( computedBounds != _bounds )
@@ -680,26 +630,26 @@ readFillStyles(ShapeRecord::FillStyles& styles, SWFStream& in,
          SWF::TagType tag, movie_definition& m, const RunResources& /*r*/)
 {
     in.ensureBytes(1);
-    boost::uint16_t FillStyle_count = in.read_u8();
-    if (tag != SWF::DEFINESHAPE)
-    {
-        if (FillStyle_count == 0xFF)
-        {
+    boost::uint16_t fillcount = in.read_u8();
+    if (tag != SWF::DEFINESHAPE) {
+        if (fillcount == 0xff) {
             in.ensureBytes(2);
-            FillStyle_count = in.read_u16();
+            fillcount = in.read_u16();
         }
     }
 
-    IF_VERBOSE_PARSE (
-        log_parse(_("  readFillStyles: count = %u"), FillStyle_count);
+    IF_VERBOSE_PARSE(
+        log_parse(_("  fill styles: %1%"), fillcount);
     );
 
     // Read the styles.
-    styles.reserve(styles.size()+FillStyle_count);
-    for (boost::uint16_t i = 0; i < FillStyle_count; ++i) {
-        // TODO: add a FillStyle constructor directly reading from stream
+    styles.reserve(styles.size() + fillcount);
+    for (boost::uint16_t i = 0; i < fillcount; ++i) {
         OptionalFillPair fp = readFills(in, tag, m, false);
         styles.push_back(fp.first);
+        IF_VERBOSE_PARSE(
+            log_parse(_("  Read fill: %1%"), fp.first);
+        );
     }
 }
 
@@ -715,8 +665,7 @@ readLineStyles(ShapeRecord::LineStyles& styles, SWFStream& in,
         log_parse(_("  readLineStyles: count = %d"), line_style_count);
     );
 
-    if (line_style_count == 0xFF)
-    {
+    if (line_style_count == 0xFF) {
         in.ensureBytes(2);
         line_style_count = in.read_u16();
         IF_VERBOSE_PARSE(
@@ -725,8 +674,7 @@ readLineStyles(ShapeRecord::LineStyles& styles, SWFStream& in,
     }
 
     // Read the styles.
-    for (int i = 0; i < line_style_count; i++)
-    {
+    for (int i = 0; i < line_style_count; i++) {
         styles.resize(styles.size() + 1);
         styles.back().read(in, tag, md, r);
     }
@@ -739,13 +687,11 @@ computeBounds(SWFRect& bounds, const ShapeRecord::Paths& paths,
 {
     bounds.set_null();
 
-    for (unsigned int i = 0; i < paths.size(); i++)
-    {
+    for (unsigned int i = 0; i < paths.size(); i++) {
         const Path& p = paths[i];
 
         unsigned thickness = 0;
-        if ( p.m_line )
-        {
+        if ( p.m_line ) {
             // For glyph shapes m_line is allowed to be 1
             // while no defined line styles are allowed.
             if (lineStyles.empty()) {
@@ -769,7 +715,12 @@ computeBounds(SWFRect& bounds, const ShapeRecord::Paths& paths,
 std::ostream&
 operator<<(std::ostream& o, const ShapeRecord& sh)
 {
-    o << "Shape Record: bounds " << sh.getBounds();
+    o << boost::format("Shape Record: bounds %1%") % sh.getBounds();
+
+    const ShapeRecord::FillStyles& fills = sh.fillStyles();
+    std::copy(fills.begin(), fills.end(),
+            std::ostream_iterator<FillStyle>(o, ","));
+
     return o;
 }
 
