@@ -1,5 +1,6 @@
 //
-//   Copyright (C) 2007, 2008, 2009, 2010, 2011 Free Software Foundation, Inc.
+//   Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -17,6 +18,11 @@
 //
 
 #include "StreamSoundBlockTag.h"
+
+#include <boost/intrusive_ptr.hpp>
+#include <boost/cstdint.hpp>
+
+#include "utility.h"
 #include "sound_handler.h" 
 #include "movie_root.h"
 #include "movie_definition.h"
@@ -25,6 +31,7 @@
 #include "SWFStream.h"
 #include "log.h"
 #include "RunResources.h"
+#include "MediaHandler.h"
 
 namespace gnash {
 namespace SWF {
@@ -38,27 +45,22 @@ StreamSoundBlockTag::executeActions(MovieClip* m, DisplayList& /*dlist*/) const
 
     if (handler) {
         // This makes it possible to stop only the stream when framejumping.
-        m->setStreamSoundId(m_handler_id);
-
-        handler->playStream(m_handler_id, _blockId);
+        m->setStreamSoundId(_handler_id);
+        handler->playStream(_handler_id, _blockId);
+        getRoot(*getObject(m)).setStreamBlock(_handler_id, _blockId);
     }
 }
 
-/* public static */
 void
 StreamSoundBlockTag::loader(SWFStream& in, TagType tag, movie_definition& m,
         const RunResources& r)
 {
-    assert(tag == SWF::SOUNDSTREAMBLOCK); // 19
+    assert(tag == SWF::SOUNDSTREAMBLOCK); 
 
     sound::sound_handler* handler = r.soundHandler(); 
 
     // If we don't have a sound_handler registered stop here
-    if (!handler)
-    {
-        // log_debug ?
-        return;
-    }
+    if (!handler) return;
 
     // Get the ID of the sound stream currently being loaded
     const int sId = m.get_loading_sound_stream_id();
@@ -77,41 +79,46 @@ StreamSoundBlockTag::loader(SWFStream& in, TagType tag, movie_definition& m,
     }
 
     media::audioCodecType format = sinfo->getFormat();
-    unsigned int sampleCount = sinfo->getSampleCount();
+
+    boost::uint16_t sampleCount;
+    boost::int16_t seekSamples = 0;
 
     // MP3 format blocks have additional info
     if (format == media::AUDIO_CODEC_MP3) {
         in.ensureBytes(4);
-        // FIXME: use these values !
-        unsigned int samplesCount = in.read_u16(); UNUSED(samplesCount);
-        unsigned int seekSamples = in.read_u16();
-        if (seekSamples) LOG_ONCE(log_unimpl(_("MP3 soundblock seek samples")));
+        // MP3 blocks have restrictions on the number of samples they can
+        // contain (due to the codec), so have a variable number of samples
+        // per block.
+        sampleCount = in.read_u16();
+        seekSamples = in.read_u16();
     }
+    else sampleCount = sinfo->getSampleCount();
 
+    // Sometimes this will be 0; in this case it serves as a synchronization
+    // point only.
     const unsigned int dataLength = in.get_tag_end_position() - in.tell();
-    if (!dataLength) {
-        IF_VERBOSE_MALFORMED_SWF(
-            LOG_ONCE(log_swferror("Empty SOUNDSTREAMBLOCK tag, seems common "
-                    "waste of space"));
-        );
-        return;
-    }
 
-    unsigned char* data = new unsigned char[dataLength];
-    const unsigned int bytesRead = in.read(reinterpret_cast<char*>(data),
-            dataLength);
+    media::MediaHandler* mh = r.mediaHandler();
+    const size_t padding = mh ? mh->getInputPaddingSize() : 0;
+
+    // Reserve padding too.
+    std::auto_ptr<SimpleBuffer> buf(new SimpleBuffer(dataLength + padding));
+    buf->resize(dataLength);
+
+    const unsigned int bytesRead = in.read((char*)buf->data(), dataLength);
     
     if (bytesRead < dataLength) {
-        delete [] data;
         throw ParserException(_("Tag boundary reported past end of stream!"));
     }
 
-    // Fill the data on the apropiate sound, and receives the starting point
+    // Fill the data on the appropiate sound, and receives the starting point
     // for later "start playing from this frame" events.
     //
-    // ownership of 'data' is transferred here
+    // TODO: the amount of sound data used should depend on the sampleCount,
+    // not on the size of the data. Currently the sound_handler ignores
+    // sampleCount completely.
     sound::sound_handler::StreamBlockId blockId =
-        handler->addSoundBlock(data, dataLength, sampleCount, sId);
+        handler->addSoundBlock(buf, sampleCount, seekSamples, sId);
 
     boost::intrusive_ptr<ControlTag> s(new StreamSoundBlockTag(sId, blockId));
 
