@@ -2,7 +2,8 @@
 // asked to do so, so that values outside of the stack are guaranteed good
 // in an appropriate scope.
 //
-//   Copyright (C) 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
+//   Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc.
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -20,7 +21,6 @@
 #ifndef GNASH_SAFESTACK_H
 #define GNASH_SAFESTACK_H
 
-#include "log.h"
 
 #include <vector>
 
@@ -125,30 +125,26 @@ public:
 	/// Shrink the stack by i entries. Does not invalidate any entries
 	/// previously given, it just sets the top for pop, push, and top
 	/// operations.
-	void drop(StackSize i)
-    {
+	void drop(StackSize i) {
         if (i > size()) throw StackException();
         _end -= i;
     }
 
 	/// Drop all stack elements reguardless of the "downstop"
-	void clear()
-	{
+	void clear() {
         _downstop = 0;
         _end = 1;
     }
 
 	/// Put a new value onto the top of the stack.  The value will be
 	/// copied.
-	void push(const T t)
-	{
+	void push(const T& t) {
         grow(1);
         top(0) = t;
     }
 
 	/// Pop the top of the stack.
-	T& pop()
-	{
+	T& pop() {
         T& ret = top(0);
         drop(1);
         return ret;
