@@ -1,7 +1,7 @@
 // VM.h: the Virtual Machine class, for Gnash
 // 
-//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010,
-//   2011 Free Software Foundation, Inc
+//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -31,17 +31,16 @@
 #include <boost/cstdint.hpp> 
 #include <boost/random.hpp>
 #include <boost/noncopyable.hpp>
-#include <boost/intrusive_ptr.hpp>
 #include <boost/array.hpp>
 
 #include "GC.h"
 #include "string_table.h"
 #include "SafeStack.h"
 #include "CallStack.h"
-#include "smart_ptr.h"
 #include "as_value.h"
 #include "namedStrings.h"
 #include "ObjectURI.h"
+#include "ConstantPool.h"
 
 // Forward declarations
 namespace gnash {
@@ -80,10 +79,9 @@ public:
 	
 	/// Initializes the VM
     //
-    /// @param version      The initial version of the VM
     /// @param root         The movie_root that owns this VM
     /// @param clock        The clock to use for advances.
-	VM(int version, movie_root& root, VirtualClock& clock);
+	VM(movie_root& root, VirtualClock& clock);
 
 	~VM();
 
@@ -249,6 +247,10 @@ public:
     /// Print stack, call stack, and registers to the specified ostream
     void dumpState(std::ostream& o, size_t limit = 0);
 
+    void setConstantPool(const ConstantPool *pool) { _constantPool = pool; }
+
+    const ConstantPool *getConstantPool() const { return _constantPool; }
+
 private:
 
 	/// Stage associated with this VM
@@ -281,6 +283,7 @@ private:
 
     RNG _rng;
 
+    const ConstantPool* _constantPool;
 };
 
 // @param lowerCaseHint if true the caller guarantees
