@@ -1,6 +1,6 @@
 // 
-//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010 Free Software
-//   Foundation, Inc
+//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -19,23 +19,21 @@
 #ifndef GNASH_FN_CALL_H
 #define GNASH_FN_CALL_H
 
-#include "as_environment.h" 
-#include "as_object.h"
-#include "as_value.h"
-#include "VM.h"
-#include "GnashException.h"
-
 #include <string>
 #include <vector>
 #include <cassert> 
 #include <ostream>
-#include <sstream>
 #include <algorithm>
 
+#include "as_object.h"
+#include "as_value.h"
+#include "VM.h"
+#include "GnashException.h"
+#include "as_environment.h"
+
+
 // Forward declarations
 namespace gnash {
-    class as_environment;
-    class as_function;
     class movie_definition;
 }
 
@@ -204,8 +202,8 @@ public:
     /// Dump arguments to given output stream
     void dump_args(std::ostream& os) const {
         for (size_t i = 0; i < nargs; ++i) {
-            if ( i ) os << ", ";
-            os << arg(i).toDebugString();
+            if (i) os << ", ";
+            os << arg(i);
         }
 	}
     
@@ -233,19 +231,6 @@ private:
 };
 
 
-/// Check that the 'this' pointer is a particular type
-//
-/// NB: this function and is deprecated.
-template<typename T>
-struct ThisIs
-{
-    typedef T value_type;
-    value_type* operator()(as_object* o) const {
-        return dynamic_cast<value_type*>(o);
-    }
-};
-
-
 /// Check that the 'this' pointer has a particular native type ('Relay').
 //
 /// This is the most likely of the cases to reflect AS behaviour.
@@ -253,7 +238,7 @@ template<typename T>
 struct ThisIsNative
 {
     typedef T value_type;
-    value_type* operator()(as_object* o) const {
+    value_type* operator()(const as_object* o) const {
         return dynamic_cast<value_type*>(o->relay());
     }
 };
@@ -265,7 +250,7 @@ template<typename T = DisplayObject>
 struct IsDisplayObject
 {
     typedef T value_type;
-    value_type* operator()(as_object* o) const {
+    value_type* operator()(const as_object* o) const {
         if (!o) return 0;
         return dynamic_cast<T*>(o->displayObject());
     }
