@@ -1,6 +1,7 @@
 // FLVParser.cpp:  Flash Video file parser, for Gnash.
 //
-//   Copyright (C) 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
+//   Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -183,15 +184,15 @@ FLVParser::parseAudioTag(const FLVTag& flvtag, const FLVAudioTag& audiotag, boos
 
 	frame = readAudioFrame(bodyLength-1, flvtag.timestamp);
 	if ( ! frame.get() ) {
-		log_error("could not read audio frame?");
+            log_error(_("could not read audio frame?"));
 	}
 
 	// If this is the first audioframe no info about the
 	// audio format has been noted, so we do that now
-	if ( !_audioInfo.get() )
-	{
+	if (!_audioInfo.get()) {
 		_audioInfo.reset(new AudioInfo(audiotag.codec, audiotag.samplerate,
-                    audiotag.samplesize, audiotag.stereo, 0, FLASH) );
+                    audiotag.samplesize, audiotag.stereo, 0,
+                    CODEC_TYPE_FLASH));
 
         if (header) {
 
@@ -260,13 +261,14 @@ FLVParser::parseVideoTag(const FLVTag& flvtag, const FLVVideoTag& videotag, boos
 	std::auto_ptr<EncodedVideoFrame> frame = readVideoFrame(bodyLength-1,
             flvtag.timestamp);
 	if ( ! frame.get() ) {
-		log_error("could not read video frame?");
+            log_error(_("could not read video frame?"));
 	}
 
 	// If this is the first videoframe no info about the
 	// video format has been noted, so we do that now
 	if ( ! _videoInfo.get() ) {
-		_videoInfo.reset(new VideoInfo(videotag.codec, 0, 0, 0, 0, FLASH));
+		_videoInfo.reset(new VideoInfo(videotag.codec, 0, 0, 0, 0,
+                    CODEC_TYPE_FLASH));
 
 		if (header) {
             // The frame is 0-padded up to the end. It may be larger than
@@ -317,7 +319,8 @@ FLVParser::parseNextTag(bool index_only)
 	//log_debug("FLVParser::parseNextTag seeking to %d", thisTagPos+4);
 	if (!_stream->seek(thisTagPos+4))
 	{
-		log_error("FLVParser::parseNextTag: can't seek to %d", thisTagPos+4);
+            log_error(_("FLVParser::parseNextTag: can't seek to %d"),
+                      thisTagPos+4);
 
 		completed = true;
 		return false;
@@ -330,8 +333,8 @@ FLVParser::parseNextTag(bool index_only)
 	if ( actuallyRead < 12 )
 	{
 		if ( actuallyRead )
-			log_error("FLVParser::parseNextTag: can't read tag info "
-                    "(needed 12 bytes, only got %d)", actuallyRead);
+                    log_error(_("FLVParser::parseNextTag: can't read tag info "
+                                "(needed 12 bytes, only got %d)"), actuallyRead);
 		// else { assert(_stream->eof(); } ?
 
 		completed = true;
@@ -429,8 +432,8 @@ FLVParser::parseNextTag(bool index_only)
 
         if ( actuallyRead < flvtag.body_size-1 )
 		{
-			log_error("FLVParser::parseNextTag: can't read metaTag (%d) "
-                    "body (needed %d bytes, only got %d)",
+                    log_error(_("FLVParser::parseNextTag: can't read metaTag (%d) "
+                                "body (needed %d bytes, only got %d)"),
 				FLV_META_TAG, flvtag.body_size, actuallyRead);
 			return false;
 		}
@@ -475,7 +478,7 @@ FLVParser::parseHeader()
 	boost::uint8_t header[9];
 	if ( _stream->read(header, 9) != 9 )
 	{
-		log_error("FLVParser::parseHeader: couldn't read 9 bytes of header");
+            log_error(_("FLVParser::parseHeader: couldn't read 9 bytes of header"));
 		return false;
 	}
 
@@ -527,7 +530,7 @@ FLVParser::readAudioFrame(boost::uint32_t dataSize, boost::uint32_t timestamp)
     std::fill(data + bytesRead, data + bufSize, 0);
 
 	if (bytesRead < dataSize) {
-		log_error("FLVParser::readAudioFrame: could only read %d/%d bytes",
+            log_error(_("FLVParser::readAudioFrame: could only read %d/%d bytes"),
                 bytesRead, dataSize);
 	}
 
@@ -565,13 +568,14 @@ void
 FLVParser::fetchMetaTags(OrderedMetaTags& tags, boost::uint64_t ts)
 {
 	boost::mutex::scoped_lock lock(_metaTagsMutex);
-	if (!_metaTags.empty())
-	{
+	if (!_metaTags.empty()) {
         MetaTags::iterator it = _metaTags.upper_bound(ts);
+
+        // Copy the first value into the return container.
         std::transform(_metaTags.begin(), it, std::back_inserter(tags),
-                SecondElement<MetaTags::value_type>());
+                boost::bind(&MetaTags::value_type::second, _1));
+
         _metaTags.erase(_metaTags.begin(), it);
-       
 	}
 }
 
