@@ -1,6 +1,7 @@
 // MediaParser.cpp:  Media file parser, for Gnash.
 //
-//   Copyright (C) 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
+//   Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -19,11 +20,13 @@
 
 
 #include "MediaParser.h"
-#include "log.h"
-#include "GnashSleep.h" // for usleep.
 
 #include <boost/bind.hpp>
 
+#include "log.h"
+#include "GnashSleep.h" // for usleep.
+#include "Id3Info.h"
+
 // Define this to get debugging output from MediaParser
 //#define GNASH_DEBUG_MEDIAPARSER
 
@@ -64,6 +67,23 @@ MediaParser::getBufferLength() const
 	return getBufferLengthNoLock();
 }
 
+/* public */
+bool
+MediaParser::isBufferEmpty() const
+{
+#ifdef LOAD_MEDIA_IN_A_SEPARATE_THREAD
+	boost::mutex::scoped_lock lock(_qMutex);
+#endif
+	return _videoFrames.empty() && _audioFrames.empty();
+}
+
+boost::optional<Id3Info>
+MediaParser::getId3Info() const
+{
+    log_error(_("No ID3 support implemented in this MediaParser"));
+    return boost::optional<Id3Info>();
+}
+
 boost::uint64_t
 MediaParser::getBufferLengthNoLock() const
 {
@@ -107,11 +127,12 @@ MediaParser::audioBufferLength() const
 	return _audioFrames.back()->timestamp - _audioFrames.front()->timestamp; 
 }
 
+/*private*/
 const EncodedVideoFrame*
 MediaParser::peekNextVideoFrame() const
 {
 #ifdef LOAD_MEDIA_IN_A_SEPARATE_THREAD
-	boost::mutex::scoped_lock lock(_qMutex);
+    // TODO: assert _qMutex is locked by this thread
 #else // ndef LOAD_MEDIA_IN_A_SEPARATE_THREAD
 	while (!parsingCompleted() && _videoInfo.get() && _videoFrames.empty())
 	{
@@ -166,6 +187,9 @@ MediaParser::nextFrameTimestamp(boost::uint64_t& ts) const
 bool
 MediaParser::nextVideoFrameTimestamp(boost::uint64_t& ts) const
 {
+#ifdef LOAD_MEDIA_IN_A_SEPARATE_THREAD
+	boost::mutex::scoped_lock lock(_qMutex);
+#endif // def LOAD_MEDIA_IN_A_SEPARATE_THREAD
 	const EncodedVideoFrame* ef = peekNextVideoFrame();
 	if ( ! ef ) return false;
 	ts = ef->timestamp();
@@ -221,17 +245,21 @@ MediaParser::nextAudioFrame()
 bool
 MediaParser::nextAudioFrameTimestamp(boost::uint64_t& ts) const
 {
+#ifdef LOAD_MEDIA_IN_A_SEPARATE_THREAD
+	boost::mutex::scoped_lock lock(_qMutex);
+#endif // def LOAD_MEDIA_IN_A_SEPARATE_THREAD
 	const EncodedAudioFrame* ef = peekNextAudioFrame();
 	if ( ! ef ) return false;
 	ts = ef->timestamp;
 	return true;
 }
 
+/*private*/
 const EncodedAudioFrame*
 MediaParser::peekNextAudioFrame() const
 {
 #ifdef LOAD_MEDIA_IN_A_SEPARATE_THREAD
-	boost::mutex::scoped_lock lock(_qMutex);
+    // TODO: assert _qMutex is locked by this thread
 #else // ndef LOAD_MEDIA_IN_A_SEPARATE_THREAD
 	while (!parsingCompleted() && _audioInfo.get() && _audioFrames.empty())
 	{
@@ -411,7 +439,14 @@ MediaParser::parserLoop()
 	while (!parserThreadKillRequested())
 	{
 		parseNextChunk();
-        	gnashSleep(100); // no rush....
+		gnashSleep(100); // thread switch 
+
+		// check for parsing complete
+		// TODO: have a setParsingComplete() function
+		//       exposed in base class for taking care
+		//       of this on appropriate time.
+		boost::mutex::scoped_lock lock(_qMutex);
+		waitIfNeeded(lock);
 	}
 }
 
