@@ -1,6 +1,7 @@
 // MediaParserFfmpeg.h: FFMEPG media parsers, for Gnash
 // 
-//   Copyright (C) 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
+//   Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc.
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -19,11 +20,13 @@
 #ifndef GNASH_MEDIAPARSER_FFMPEG_H
 #define GNASH_MEDIAPARSER_FFMPEG_H
 
-#include "MediaParser.h" // for inheritance
-#include "ffmpegHeaders.h"
-
 #include <boost/scoped_array.hpp>
 #include <memory>
+#include <boost/optional.hpp>
+
+#include "MediaParser.h" // for inheritance
+#include "ffmpegHeaders.h"
+#include "Id3Info.h"
 
 // Forward declaration
 namespace gnash {
@@ -90,6 +93,8 @@ public:
 	// See dox in MediaParser.h
 	virtual boost::uint64_t getBytesLoaded() const;
 
+    virtual boost::optional<Id3Info> getId3Info() const;
+
 private:
 
 	/// Initialize parser, figuring format and 
@@ -175,6 +180,8 @@ private:
 
 	/// Make an EncodedAudioFrame from an AVPacket and push to buffer
 	bool parseAudioFrame(AVPacket& packet);
+
+    boost::optional<Id3Info> _id3Object;
 };
 
 
