@@ -1,5 +1,6 @@
 /* 
- *   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
+ *   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
+ *   Free Software Foundation, Inc.
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,7 +25,8 @@
 #include "GnashKey.h" // for namespace key
 #include "RGBA.h" // for rgba class (composition)
 
-#include <iostream> 
+#include <cmath>
+#include <ostream> 
 
 namespace gnash {
 
@@ -129,7 +131,7 @@ public:
 	/// Return true if a and b are below a given tolerance
 	static bool fuzzyEqual(int a, int b, int tol)
 	{
-		return abs(a-b) <= tol;
+		return std::abs(a-b) <= tol;
 	}
 
 private:
