@@ -1,6 +1,6 @@
 /***********************************************************************
  *
- *   Copyright (C) 2005, 2006, 2009, 2010 Free Software Foundation, Inc.
+ *   Copyright (C) 2005, 2006, 2009, 2010, 2011 Free Software Foundation, Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -123,7 +123,7 @@ main(int argc, char** argv)
   // replace the shape with another one
   if ( SWFMovie_replace(mo, it1, (SWFBlock)sh2) )
   {
-    abort(); 
+    return 1;
   }
   SWFMovie_nextFrame(mo); // frame 6
   
