@@ -1,5 +1,6 @@
 /* 
- *   Copyright (C) 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
+ *   Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012
+ *   Free Software Foundation, Inc.
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -47,11 +48,6 @@ main(int /*argc*/, char** /*argv*/)
   rgba red(255,0,0,255);   //start color
   rgba green(0,255,0,255); //end color
 
-  int start_x = 0;  //start coordinates of LU point
-  int start_y = 0;
-  int end_x = 700;  //end coordinates of LU point
-  int end_y = 500;
-
   MovieClip* root = tester.getRootMovie();
   assert(root);
   check_equals(root->get_frame_count(), 7);
