@@ -1,5 +1,6 @@
 /* 
- *   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
+ *   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
+ *   Free Software Foundation, Inc.
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,7 +29,6 @@
 #include "log.h"
 #include "Point2d.h"
 #include "VM.h"
-#include "string_table.h"
 #include "as_value.h"
 
 #include "check.h"
@@ -65,7 +65,6 @@ main(int /*argc*/, char** /*argv*/)
 
 	MovieClip* root = tester.getRootMovie();
 	VM& vm = getVM(*getObject(root));
-	string_table& st = vm.getStringTable();
 
 	check_equals(root->get_frame_count(), 1);
 
@@ -158,9 +157,9 @@ main(int /*argc*/, char** /*argv*/)
 
 	as_value eot;
         
-    getObject(root)->get_member(st.find("testcompleted"), &eot);
+    getObject(root)->get_member(getURI(vm, "testcompleted"), &eot);
         
 	//cerr << "EOT is " << eot.to_debug_string() << endl;
-	check(eot.to_bool());
+	check(eot.to_bool(8));
 }
 
