@@ -1,6 +1,6 @@
 // 
-//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010 Free Software
-//   Foundation, Inc
+//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -20,13 +20,14 @@
 #include "gnashconfig.h"
 #endif
 
+#include <vector>
+#include <string>
+#include <iostream>
+
 #include "rc.h"
 #include "gst/gst.h"
 #include <gst/interfaces/propertyprobe.h>
 
-#include <vector>
-#include <string>
-
 namespace {
     //get rc file for webcam selection
     gnash::RcInitFile& rcfile = gnash::RcInitFile::getDefaultInstance();
@@ -50,7 +51,7 @@ data::data() {
 
 gint numDuplicates = 0;
 
-gint findVidDevs(std::vector<data*>& vidVect) {
+size_t findVidDevs(std::vector<data*>& vidVect) {
     gint numdevs = 0;
     
     //vid test source
@@ -86,7 +87,7 @@ gint findVidDevs(std::vector<data*>& vidVect) {
         g_object_get (element, "device-name", &dev_name, NULL);
         gst_element_set_state (element, GST_STATE_NULL);
         if (strcmp(dev_name, "null") == 0) {
-            g_print("no v4l video sources found\n");
+            std::cout << "no v4l video sources found" << std::endl;
         }
         else { 
             vidVect.push_back(new data);
@@ -105,7 +106,6 @@ gint findVidDevs(std::vector<data*>& vidVect) {
     probe = NULL;
     element = NULL;
     devarr = NULL;
-    gint g;
     
     element = gst_element_factory_make ("v4l2src", "v4l2vidsrc");
     probe = GST_PROPERTY_PROBE (element);
@@ -120,7 +120,7 @@ gint findVidDevs(std::vector<data*>& vidVect) {
         g_object_get (element, "device-name", &dev_name, NULL);
         gst_element_set_state (element, GST_STATE_NULL);
         if (strcmp(dev_name, "null") == 0) {
-            g_print("no v4l2 video sources found.\n");
+            std::cout << "no v4l2 video sources found." << std::endl;
         }
         else {
             vidVect.push_back(new data);
@@ -129,7 +129,7 @@ gint findVidDevs(std::vector<data*>& vidVect) {
             vidVect[numdevs]->deviceNumber = numdevs;
             //mark duplicates (we like v4l2 sources more than v4l, so if
             //they're both detected, mark the v4l source as a duplicate)
-            for (g=1; g < (vidVect.size()-1); g++) {
+            for (size_t g=1; g < (vidVect.size()-1); g++) {
                 if (strcmp(vidVect[numdevs]->deviceName,
                         vidVect[g]->deviceName) == 0) {
                     vidVect[g]->duplicate = true;
@@ -148,36 +148,44 @@ gint findVidDevs(std::vector<data*>& vidVect) {
 int main () {
     //initialize gstreamer to probe for devs
     gst_init(NULL, NULL);
-    gint numdevs = 0;
+    size_t numdevs = 0;
     std::vector<data*> vidVector;
     
     int fromrc = rcfile.getWebcamDevice();
     
     if (fromrc == -1) {
-        g_print("\nUse this utility to set your desired default webcam device.\n");
+        std::cout << std::endl
+                  << "Use this utility to set your desired default webcam device." << std::endl;
         numdevs = findVidDevs(vidVector);
-        g_print("\nINFO: these devices were ignored because they are supported by both");
-        g_print("\nvideo4linux and video4linux2:\n\n");
+        std::cout << std::endl
+             << "INFO: these devices were ignored because they are supported by both" << std::endl
+             << "video4linux and video4linux2:" << std::endl << std::endl;
         for (size_t i = 0; i < numdevs; ++i) {
             if (vidVector[i]->duplicate == true) {
-                g_print("    %s (%s)\n", vidVector[i]->deviceName, vidVector[i]->deviceType);
+                std::cout << "    " << vidVector[i]->deviceName
+                     << " (" << vidVector[i]->deviceType << ")" << std::endl;
             }
         }
-        g_print("\nGnash interacts with v4l2 sources better than v4l sources, thus the");
-        g_print("\nv4l sources will not be printed in the list below.\n");
-        g_print("\nFound %d video devices: \n\n", (numdevs - numDuplicates));
+        std::cout << std::endl
+             << "Gnash interacts with v4l2 sources better than v4l sources, thus the" << std::endl
+             << "v4l sources will not be printed in the list below." << std::endl
+             << std::endl
+             << "Found " << (numdevs - numDuplicates) 
+             << " video devices: " << std::endl << std::endl;
         gint counter = 0;
         for (size_t i = 0; i < numdevs; ++i)
         {
             if (i == 0 && (vidVector[i] != 0)) {
-                g_print("    %d. Video Test Source (videotestsrc)\n", i, i);
+                std::cout << "    " << i
+                     << ". Video Test Source (videotestsrc)" << std::endl;
                 counter++;
             } else if (i == 0 && (vidVector[i] == 0)) {
-                g_print("no test video device available");
+                std::cout << "no test video device available";
             } else {
                 if (vidVector[i]->duplicate != true) {
-                    g_print("    %d. %s (%s)\n", counter, vidVector[i]->deviceName,
-                            vidVector[i]->deviceType);
+                    std::cout << "    " << counter << ". "
+                         << vidVector[i]->deviceName
+                         << " (" << vidVector[i]->deviceType << ")" << std::endl;
                     counter++;
                 }
             }
@@ -187,8 +195,9 @@ int main () {
         std::string fromCin;
         do {
             dev_select = -1;
-            g_print("\nChoose the device you would like to use (0-%d): ",
-                (numdevs - numDuplicates - 1));
+            std::cout << std::endl
+                 << "Choose the device you would like to use (0-"
+                 << (numdevs - numDuplicates - 1) << "): ";
             std::cin >> fromCin;
             if (fromCin.size() != 1) {
                 dev_select = -1;
@@ -197,24 +206,28 @@ int main () {
             } else {
                 dev_select = atoi(fromCin.c_str());
             }
-            if ((dev_select < 0) || (dev_select > (numdevs - numDuplicates - 1))) {
-                g_print("You must make a valid device selection\n");
+            if ((dev_select < 0) || (dev_select > ((int)numdevs - numDuplicates - 1))) {
+                std::cout << "You must make a valid device selection" << std::endl;
             }
-        } while ((dev_select < 0) || (dev_select > (numdevs - numDuplicates - 1)));
-        g_print("\nTo select this camera, add this line to your gnashrc file:\n");
-        g_print("set webcamDevice %d\n", vidVector[dev_select + numDuplicates]->deviceNumber);
+        } while ((dev_select < 0) || (dev_select > ((int)numdevs - numDuplicates - 1)));
+        std::cout << std::endl
+             << "To select this camera, add this line to your gnashrc file:" << std::endl
+             << "set webcamDevice "
+             << (vidVector[dev_select + numDuplicates]->deviceNumber) << std::endl;
     } else {
         numdevs = findVidDevs(vidVector);
-        if (fromrc <= (vidVector.size() - 1)) {
-            g_print("\nThe gnashrc file reports default webcam is set to:\n");
-            g_print("%s (%s)\n", vidVector[fromrc]->deviceName,
-                vidVector[fromrc]->deviceType);
-            g_print("To change this setting, delete the 'set webcamDevice' line\n");
-            g_print("from your gnashrc file and re-run this program.\n\n");
+        if ((size_t)fromrc <= (vidVector.size() - 1)) {
+            std::cout << std::endl
+                 << "The gnashrc file reports default webcam is set to:" << std::endl
+                 << vidVector[fromrc]->deviceName
+                 << " (" << vidVector[fromrc]->deviceType << ")" << std::endl
+                 << "To change this setting, delete the 'set webcamDevice' line" << std::endl
+                 << "from your gnashrc file and re-run this program." << std::endl << std::endl;
         } else {
-            g_print("\nYou have an invalid webcam chosen in your gnashrc file.\n");
-            g_print("Try reattaching the device or deleting the value from gnashrc\n");
-            g_print("and running this program again\n");
+          std::cout << std::endl
+               << "You have an invalid webcam chosen in your gnashrc file." << std::endl
+               << "Try reattaching the device or deleting the value from gnashrc" << std::endl
+               << "and running this program again" << std::endl;
         }
     }
     return 0;
